import { HttpHandlerOptions as __HttpHandlerOptions } from "@aws-sdk/types";
import { BatchUpdateClusterCommandInput, BatchUpdateClusterCommandOutput } from "./commands/BatchUpdateClusterCommand";
import { CopySnapshotCommandInput, CopySnapshotCommandOutput } from "./commands/CopySnapshotCommand";
import { CreateACLCommandInput, CreateACLCommandOutput } from "./commands/CreateACLCommand";
import { CreateClusterCommandInput, CreateClusterCommandOutput } from "./commands/CreateClusterCommand";
import { CreateParameterGroupCommandInput, CreateParameterGroupCommandOutput } from "./commands/CreateParameterGroupCommand";
import { CreateSnapshotCommandInput, CreateSnapshotCommandOutput } from "./commands/CreateSnapshotCommand";
import { CreateSubnetGroupCommandInput, CreateSubnetGroupCommandOutput } from "./commands/CreateSubnetGroupCommand";
import { CreateUserCommandInput, CreateUserCommandOutput } from "./commands/CreateUserCommand";
import { DeleteACLCommandInput, DeleteACLCommandOutput } from "./commands/DeleteACLCommand";
import { DeleteClusterCommandInput, DeleteClusterCommandOutput } from "./commands/DeleteClusterCommand";
import { DeleteParameterGroupCommandInput, DeleteParameterGroupCommandOutput } from "./commands/DeleteParameterGroupCommand";
import { DeleteSnapshotCommandInput, DeleteSnapshotCommandOutput } from "./commands/DeleteSnapshotCommand";
import { DeleteSubnetGroupCommandInput, DeleteSubnetGroupCommandOutput } from "./commands/DeleteSubnetGroupCommand";
import { DeleteUserCommandInput, DeleteUserCommandOutput } from "./commands/DeleteUserCommand";
import { DescribeACLsCommandInput, DescribeACLsCommandOutput } from "./commands/DescribeACLsCommand";
import { DescribeClustersCommandInput, DescribeClustersCommandOutput } from "./commands/DescribeClustersCommand";
import { DescribeEngineVersionsCommandInput, DescribeEngineVersionsCommandOutput } from "./commands/DescribeEngineVersionsCommand";
import { DescribeEventsCommandInput, DescribeEventsCommandOutput } from "./commands/DescribeEventsCommand";
import { DescribeParameterGroupsCommandInput, DescribeParameterGroupsCommandOutput } from "./commands/DescribeParameterGroupsCommand";
import { DescribeParametersCommandInput, DescribeParametersCommandOutput } from "./commands/DescribeParametersCommand";
import { DescribeServiceUpdatesCommandInput, DescribeServiceUpdatesCommandOutput } from "./commands/DescribeServiceUpdatesCommand";
import { DescribeSnapshotsCommandInput, DescribeSnapshotsCommandOutput } from "./commands/DescribeSnapshotsCommand";
import { DescribeSubnetGroupsCommandInput, DescribeSubnetGroupsCommandOutput } from "./commands/DescribeSubnetGroupsCommand";
import { DescribeUsersCommandInput, DescribeUsersCommandOutput } from "./commands/DescribeUsersCommand";
import { FailoverShardCommandInput, FailoverShardCommandOutput } from "./commands/FailoverShardCommand";
import { ListAllowedNodeTypeUpdatesCommandInput, ListAllowedNodeTypeUpdatesCommandOutput } from "./commands/ListAllowedNodeTypeUpdatesCommand";
import { ListTagsCommandInput, ListTagsCommandOutput } from "./commands/ListTagsCommand";
import { ResetParameterGroupCommandInput, ResetParameterGroupCommandOutput } from "./commands/ResetParameterGroupCommand";
import { TagResourceCommandInput, TagResourceCommandOutput } from "./commands/TagResourceCommand";
import { UntagResourceCommandInput, UntagResourceCommandOutput } from "./commands/UntagResourceCommand";
import { UpdateACLCommandInput, UpdateACLCommandOutput } from "./commands/UpdateACLCommand";
import { UpdateClusterCommandInput, UpdateClusterCommandOutput } from "./commands/UpdateClusterCommand";
import { UpdateParameterGroupCommandInput, UpdateParameterGroupCommandOutput } from "./commands/UpdateParameterGroupCommand";
import { UpdateSubnetGroupCommandInput, UpdateSubnetGroupCommandOutput } from "./commands/UpdateSubnetGroupCommand";
import { UpdateUserCommandInput, UpdateUserCommandOutput } from "./commands/UpdateUserCommand";
import { MemoryDBClient } from "./MemoryDBClient";
/**
 * <p>MemoryDB for Redis is a fully managed, Redis-compatible, in-memory database that delivers ultra-fast performance and Multi-AZ durability for modern applications built using microservices architectures.
 *
 *        MemoryDB stores the entire database in-memory, enabling low latency and high throughput data access. It is compatible with Redis, a popular open source data store, enabling you to leverage Redis’ flexible and friendly data structures, APIs, and commands.</p>
 */
export declare class MemoryDB extends MemoryDBClient {
    /**
     * <p>Apply the service update to a list of clusters supplied. For more information on service updates and applying them, see <a href="https://docs.aws.amazon.com/MemoryDB/latest/devguide/managing-updates.html#applying-updates">Applying the service updates</a>.</p>
     */
    batchUpdateCluster(args: BatchUpdateClusterCommandInput, options?: __HttpHandlerOptions): Promise<BatchUpdateClusterCommandOutput>;
    batchUpdateCluster(args: BatchUpdateClusterCommandInput, cb: (err: any, data?: BatchUpdateClusterCommandOutput) => void): void;
    batchUpdateCluster(args: BatchUpdateClusterCommandInput, options: __HttpHandlerOptions, cb: (err: any, data?: BatchUpdateClusterCommandOutput) => void): void;
    /**
     * <p>Makes a copy of an existing snapshot.</p>
     */
    copySnapshot(args: CopySnapshotCommandInput, options?: __HttpHandlerOptions): Promise<CopySnapshotCommandOutput>;
    copySnapshot(args: CopySnapshotCommandInput, cb: (err: any, data?: CopySnapshotCommandOutput) => void): void;
    copySnapshot(args: CopySnapshotCommandInput, options: __HttpHandlerOptions, cb: (err: any, data?: CopySnapshotCommandOutput) => void): void;
    /**
     * <p>Creates an Access Control List. For more information, see <a href="https://docs.aws.amazon.com/MemoryDB/latest/devguide/clusters.acls.html">Authenticating users with Access Contol Lists (ACLs)</a>.</p>
     */
    createACL(args: CreateACLCommandInput, options?: __HttpHandlerOptions): Promise<CreateACLCommandOutput>;
    createACL(args: CreateACLCommandInput, cb: (err: any, data?: CreateACLCommandOutput) => void): void;
    createACL(args: CreateACLCommandInput, options: __HttpHandlerOptions, cb: (err: any, data?: CreateACLCommandOutput) => void): void;
    /**
     * <p>Creates a cluster. All nodes in the cluster run the same protocol-compliant engine software.</p>
     */
    createCluster(args: CreateClusterCommandInput, options?: __HttpHandlerOptions): Promise<CreateClusterCommandOutput>;
    createCluster(args: CreateClusterCommandInput, cb: (err: any, data?: CreateClusterCommandOutput) => void): void;
    createCluster(args: CreateClusterCommandInput, options: __HttpHandlerOptions, cb: (err: any, data?: CreateClusterCommandOutput) => void): void;
    /**
     * <p>Creates a new MemoryDB parameter group. A parameter group is a collection of parameters and their values that are applied to all of the nodes in any cluster. For
     *          more information, see <a href="https://docs.aws.amazon.com/MemoryDB/latest/devguide/parametergroups.html">Configuring engine parameters using parameter groups</a>.
     *
     *          </p>
     */
    createParameterGroup(args: CreateParameterGroupCommandInput, options?: __HttpHandlerOptions): Promise<CreateParameterGroupCommandOutput>;
    createParameterGroup(args: CreateParameterGroupCommandInput, cb: (err: any, data?: CreateParameterGroupCommandOutput) => void): void;
    createParameterGroup(args: CreateParameterGroupCommandInput, options: __HttpHandlerOptions, cb: (err: any, data?: CreateParameterGroupCommandOutput) => void): void;
    /**
     * <p>Creates a copy of an entire cluster at a specific moment in time.</p>
     */
    createSnapshot(args: CreateSnapshotCommandInput, options?: __HttpHandlerOptions): Promise<CreateSnapshotCommandOutput>;
    createSnapshot(args: CreateSnapshotCommandInput, cb: (err: any, data?: CreateSnapshotCommandOutput) => void): void;
    createSnapshot(args: CreateSnapshotCommandInput, options: __HttpHandlerOptions, cb: (err: any, data?: CreateSnapshotCommandOutput) => void): void;
    /**
     * <p>Creates a subnet group. A subnet group is a collection of subnets (typically private) that you can designate for your clusters running in an Amazon Virtual Private Cloud (VPC) environment.
     *
     *          When you create a cluster in an Amazon VPC, you must specify a subnet group. MemoryDB uses that subnet group to choose a subnet and IP addresses within that subnet to associate with your nodes.
     *          For more information, see <a href="https://docs.aws.amazon.com/MemoryDB/latest/devguide/subnetgroups.html">Subnets and subnet groups</a>.</p>
     */
    createSubnetGroup(args: CreateSubnetGroupCommandInput, options?: __HttpHandlerOptions): Promise<CreateSubnetGroupCommandOutput>;
    createSubnetGroup(args: CreateSubnetGroupCommandInput, cb: (err: any, data?: CreateSubnetGroupCommandOutput) => void): void;
    createSubnetGroup(args: CreateSubnetGroupCommandInput, options: __HttpHandlerOptions, cb: (err: any, data?: CreateSubnetGroupCommandOutput) => void): void;
    /**
     * <p>Creates a MemoryDB user. For more information, see <a href="https://docs.aws.amazon.com/MemoryDB/latest/devguide/clusters.acls.html">Authenticating users with Access Contol Lists (ACLs)</a>.</p>
     */
    createUser(args: CreateUserCommandInput, options?: __HttpHandlerOptions): Promise<CreateUserCommandOutput>;
    createUser(args: CreateUserCommandInput, cb: (err: any, data?: CreateUserCommandOutput) => void): void;
    createUser(args: CreateUserCommandInput, options: __HttpHandlerOptions, cb: (err: any, data?: CreateUserCommandOutput) => void): void;
    /**
     * <p>Deletes an Access Control List. The ACL must first be disassociated from the cluster before it can be deleted. For more information, see <a href="https://docs.aws.amazon.com/MemoryDB/latest/devguide/clusters.acls.html">Authenticating users with Access Contol Lists (ACLs)</a>.</p>
     */
    deleteACL(args: DeleteACLCommandInput, options?: __HttpHandlerOptions): Promise<DeleteACLCommandOutput>;
    deleteACL(args: DeleteACLCommandInput, cb: (err: any, data?: DeleteACLCommandOutput) => void): void;
    deleteACL(args: DeleteACLCommandInput, options: __HttpHandlerOptions, cb: (err: any, data?: DeleteACLCommandOutput) => void): void;
    /**
     * <p>Deletes a cluster. It also deletes all associated nodes and node endpoints</p>
     */
    deleteCluster(args: DeleteClusterCommandInput, options?: __HttpHandlerOptions): Promise<DeleteClusterCommandOutput>;
    deleteCluster(args: DeleteClusterCommandInput, cb: (err: any, data?: DeleteClusterCommandOutput) => void): void;
    deleteCluster(args: DeleteClusterCommandInput, options: __HttpHandlerOptions, cb: (err: any, data?: DeleteClusterCommandOutput) => void): void;
    /**
     * <p>Deletes the specified parameter group. You cannot delete a parameter group if it is associated with any clusters.
     *          You cannot delete the default parameter groups in your account.</p>
     */
    deleteParameterGroup(args: DeleteParameterGroupCommandInput, options?: __HttpHandlerOptions): Promise<DeleteParameterGroupCommandOutput>;
    deleteParameterGroup(args: DeleteParameterGroupCommandInput, cb: (err: any, data?: DeleteParameterGroupCommandOutput) => void): void;
    deleteParameterGroup(args: DeleteParameterGroupCommandInput, options: __HttpHandlerOptions, cb: (err: any, data?: DeleteParameterGroupCommandOutput) => void): void;
    /**
     * <p>Deletes an existing snapshot. When you receive a successful response from this operation, MemoryDB immediately begins deleting the snapshot; you cannot cancel or revert this operation.</p>
     */
    deleteSnapshot(args: DeleteSnapshotCommandInput, options?: __HttpHandlerOptions): Promise<DeleteSnapshotCommandOutput>;
    deleteSnapshot(args: DeleteSnapshotCommandInput, cb: (err: any, data?: DeleteSnapshotCommandOutput) => void): void;
    deleteSnapshot(args: DeleteSnapshotCommandInput, options: __HttpHandlerOptions, cb: (err: any, data?: DeleteSnapshotCommandOutput) => void): void;
    /**
     * <p>Deletes a subnet group. You cannot delete a default subnet group or one that is associated with any clusters.</p>
     */
    deleteSubnetGroup(args: DeleteSubnetGroupCommandInput, options?: __HttpHandlerOptions): Promise<DeleteSubnetGroupCommandOutput>;
    deleteSubnetGroup(args: DeleteSubnetGroupCommandInput, cb: (err: any, data?: DeleteSubnetGroupCommandOutput) => void): void;
    deleteSubnetGroup(args: DeleteSubnetGroupCommandInput, options: __HttpHandlerOptions, cb: (err: any, data?: DeleteSubnetGroupCommandOutput) => void): void;
    /**
     * <p>Deletes a user. The user will be removed from all ACLs and in turn removed from all clusters.</p>
     */
    deleteUser(args: DeleteUserCommandInput, options?: __HttpHandlerOptions): Promise<DeleteUserCommandOutput>;
    deleteUser(args: DeleteUserCommandInput, cb: (err: any, data?: DeleteUserCommandOutput) => void): void;
    deleteUser(args: DeleteUserCommandInput, options: __HttpHandlerOptions, cb: (err: any, data?: DeleteUserCommandOutput) => void): void;
    /**
     * <p>Returns a list of ACLs</p>
     */
    describeACLs(args: DescribeACLsCommandInput, options?: __HttpHandlerOptions): Promise<DescribeACLsCommandOutput>;
    describeACLs(args: DescribeACLsCommandInput, cb: (err: any, data?: DescribeACLsCommandOutput) => void): void;
    describeACLs(args: DescribeACLsCommandInput, options: __HttpHandlerOptions, cb: (err: any, data?: DescribeACLsCommandOutput) => void): void;
    /**
     * <p>Returns information about all provisioned clusters if no cluster identifier is specified, or about a specific cluster if a cluster name is supplied.</p>
     */
    describeClusters(args: DescribeClustersCommandInput, options?: __HttpHandlerOptions): Promise<DescribeClustersCommandOutput>;
    describeClusters(args: DescribeClustersCommandInput, cb: (err: any, data?: DescribeClustersCommandOutput) => void): void;
    describeClusters(args: DescribeClustersCommandInput, options: __HttpHandlerOptions, cb: (err: any, data?: DescribeClustersCommandOutput) => void): void;
    /**
     * <p>Returns a list of the available Redis engine versions.</p>
     */
    describeEngineVersions(args: DescribeEngineVersionsCommandInput, options?: __HttpHandlerOptions): Promise<DescribeEngineVersionsCommandOutput>;
    describeEngineVersions(args: DescribeEngineVersionsCommandInput, cb: (err: any, data?: DescribeEngineVersionsCommandOutput) => void): void;
    describeEngineVersions(args: DescribeEngineVersionsCommandInput, options: __HttpHandlerOptions, cb: (err: any, data?: DescribeEngineVersionsCommandOutput) => void): void;
    /**
     * <p>Returns events related to clusters, security groups, and parameter groups. You can obtain events specific to a particular cluster, security group, or parameter group by providing the name as a parameter.
     *
     *          By default, only the events occurring within the last hour are returned; however, you can retrieve up to 14 days' worth of events if necessary.</p>
     */
    describeEvents(args: DescribeEventsCommandInput, options?: __HttpHandlerOptions): Promise<DescribeEventsCommandOutput>;
    describeEvents(args: DescribeEventsCommandInput, cb: (err: any, data?: DescribeEventsCommandOutput) => void): void;
    describeEvents(args: DescribeEventsCommandInput, options: __HttpHandlerOptions, cb: (err: any, data?: DescribeEventsCommandOutput) => void): void;
    /**
     * <p>Returns a list of parameter group descriptions. If a parameter group name is specified, the list contains only the descriptions for that group.</p>
     */
    describeParameterGroups(args: DescribeParameterGroupsCommandInput, options?: __HttpHandlerOptions): Promise<DescribeParameterGroupsCommandOutput>;
    describeParameterGroups(args: DescribeParameterGroupsCommandInput, cb: (err: any, data?: DescribeParameterGroupsCommandOutput) => void): void;
    describeParameterGroups(args: DescribeParameterGroupsCommandInput, options: __HttpHandlerOptions, cb: (err: any, data?: DescribeParameterGroupsCommandOutput) => void): void;
    /**
     * <p>Returns the detailed parameter list for a particular parameter group.</p>
     */
    describeParameters(args: DescribeParametersCommandInput, options?: __HttpHandlerOptions): Promise<DescribeParametersCommandOutput>;
    describeParameters(args: DescribeParametersCommandInput, cb: (err: any, data?: DescribeParametersCommandOutput) => void): void;
    describeParameters(args: DescribeParametersCommandInput, options: __HttpHandlerOptions, cb: (err: any, data?: DescribeParametersCommandOutput) => void): void;
    /**
     * <p>Returns details of the service updates</p>
     */
    describeServiceUpdates(args: DescribeServiceUpdatesCommandInput, options?: __HttpHandlerOptions): Promise<DescribeServiceUpdatesCommandOutput>;
    describeServiceUpdates(args: DescribeServiceUpdatesCommandInput, cb: (err: any, data?: DescribeServiceUpdatesCommandOutput) => void): void;
    describeServiceUpdates(args: DescribeServiceUpdatesCommandInput, options: __HttpHandlerOptions, cb: (err: any, data?: DescribeServiceUpdatesCommandOutput) => void): void;
    /**
     * <p>Returns information about cluster snapshots. By default, DescribeSnapshots lists all of your snapshots; it can optionally describe a single snapshot,
     *          or just the snapshots associated with a particular cluster.</p>
     */
    describeSnapshots(args: DescribeSnapshotsCommandInput, options?: __HttpHandlerOptions): Promise<DescribeSnapshotsCommandOutput>;
    describeSnapshots(args: DescribeSnapshotsCommandInput, cb: (err: any, data?: DescribeSnapshotsCommandOutput) => void): void;
    describeSnapshots(args: DescribeSnapshotsCommandInput, options: __HttpHandlerOptions, cb: (err: any, data?: DescribeSnapshotsCommandOutput) => void): void;
    /**
     * <p>Returns a list of subnet group descriptions. If a subnet group name is specified, the list contains only the description of that group.</p>
     */
    describeSubnetGroups(args: DescribeSubnetGroupsCommandInput, options?: __HttpHandlerOptions): Promise<DescribeSubnetGroupsCommandOutput>;
    describeSubnetGroups(args: DescribeSubnetGroupsCommandInput, cb: (err: any, data?: DescribeSubnetGroupsCommandOutput) => void): void;
    describeSubnetGroups(args: DescribeSubnetGroupsCommandInput, options: __HttpHandlerOptions, cb: (err: any, data?: DescribeSubnetGroupsCommandOutput) => void): void;
    /**
     * <p>Returns a list of users.</p>
     */
    describeUsers(args: DescribeUsersCommandInput, options?: __HttpHandlerOptions): Promise<DescribeUsersCommandOutput>;
    describeUsers(args: DescribeUsersCommandInput, cb: (err: any, data?: DescribeUsersCommandOutput) => void): void;
    describeUsers(args: DescribeUsersCommandInput, options: __HttpHandlerOptions, cb: (err: any, data?: DescribeUsersCommandOutput) => void): void;
    /**
     * <p>Used to failover a shard</p>
     */
    failoverShard(args: FailoverShardCommandInput, options?: __HttpHandlerOptions): Promise<FailoverShardCommandOutput>;
    failoverShard(args: FailoverShardCommandInput, cb: (err: any, data?: FailoverShardCommandOutput) => void): void;
    failoverShard(args: FailoverShardCommandInput, options: __HttpHandlerOptions, cb: (err: any, data?: FailoverShardCommandOutput) => void): void;
    /**
     * <p>Lists all available node types that you can scale to from your cluster's current node type.
     *
     *          When you use the UpdateCluster operation to scale your cluster, the value of the NodeType parameter must be one of the node types returned by this operation.</p>
     */
    listAllowedNodeTypeUpdates(args: ListAllowedNodeTypeUpdatesCommandInput, options?: __HttpHandlerOptions): Promise<ListAllowedNodeTypeUpdatesCommandOutput>;
    listAllowedNodeTypeUpdates(args: ListAllowedNodeTypeUpdatesCommandInput, cb: (err: any, data?: ListAllowedNodeTypeUpdatesCommandOutput) => void): void;
    listAllowedNodeTypeUpdates(args: ListAllowedNodeTypeUpdatesCommandInput, options: __HttpHandlerOptions, cb: (err: any, data?: ListAllowedNodeTypeUpdatesCommandOutput) => void): void;
    /**
     * <p>Lists all tags currently on a named resource.
     *
     *          A tag is a key-value pair where the key and value are case-sensitive. You can use tags to categorize and track your MemoryDB resources.
     *          For more information, see <a href="https://docs.aws.amazon.com/MemoryDB/latest/devguide/Tagging-Resources.html">Tagging your MemoryDB resources</a>
     *          </p>
     */
    listTags(args: ListTagsCommandInput, options?: __HttpHandlerOptions): Promise<ListTagsCommandOutput>;
    listTags(args: ListTagsCommandInput, cb: (err: any, data?: ListTagsCommandOutput) => void): void;
    listTags(args: ListTagsCommandInput, options: __HttpHandlerOptions, cb: (err: any, data?: ListTagsCommandOutput) => void): void;
    /**
     * <p>Modifies the parameters of a parameter group to the engine or system default value. You can reset specific parameters by submitting a list of parameter names. To reset the entire parameter group, specify the AllParameters and ParameterGroupName parameters.</p>
     */
    resetParameterGroup(args: ResetParameterGroupCommandInput, options?: __HttpHandlerOptions): Promise<ResetParameterGroupCommandOutput>;
    resetParameterGroup(args: ResetParameterGroupCommandInput, cb: (err: any, data?: ResetParameterGroupCommandOutput) => void): void;
    resetParameterGroup(args: ResetParameterGroupCommandInput, options: __HttpHandlerOptions, cb: (err: any, data?: ResetParameterGroupCommandOutput) => void): void;
    /**
     * <p>A tag is a key-value pair where the key and value are case-sensitive. You can use tags to categorize and track all your MemoryDB resources.
     *
     *          When you add or remove tags on clusters, those actions will be replicated to all nodes in the cluster. For more information, see
     *
     *          <a href="https://docs.aws.amazon.com/MemoryDB/latest/devguide/iam.resourcelevelpermissions.html">Resource-level permissions</a>.</p>
     *
     *          <p>For example, you can use cost-allocation tags to your MemoryDB resources, Amazon generates a cost allocation report as a comma-separated value
     *           (CSV) file with your usage and costs aggregated by your tags. You can apply tags that represent business categories
     *           (such as cost centers, application names, or owners) to organize your costs across multiple services.
     *
     *          For more information, see <a href="https://docs.aws.amazon.com/MemoryDB/latest/devguide/tagging.html">Using Cost Allocation Tags</a>.</p>
     */
    tagResource(args: TagResourceCommandInput, options?: __HttpHandlerOptions): Promise<TagResourceCommandOutput>;
    tagResource(args: TagResourceCommandInput, cb: (err: any, data?: TagResourceCommandOutput) => void): void;
    tagResource(args: TagResourceCommandInput, options: __HttpHandlerOptions, cb: (err: any, data?: TagResourceCommandOutput) => void): void;
    /**
     * <p>Use this operation to remove tags on a resource</p>
     */
    untagResource(args: UntagResourceCommandInput, options?: __HttpHandlerOptions): Promise<UntagResourceCommandOutput>;
    untagResource(args: UntagResourceCommandInput, cb: (err: any, data?: UntagResourceCommandOutput) => void): void;
    untagResource(args: UntagResourceCommandInput, options: __HttpHandlerOptions, cb: (err: any, data?: UntagResourceCommandOutput) => void): void;
    /**
     * <p>Changes the list of users that belong to the Access Control List.</p>
     */
    updateACL(args: UpdateACLCommandInput, options?: __HttpHandlerOptions): Promise<UpdateACLCommandOutput>;
    updateACL(args: UpdateACLCommandInput, cb: (err: any, data?: UpdateACLCommandOutput) => void): void;
    updateACL(args: UpdateACLCommandInput, options: __HttpHandlerOptions, cb: (err: any, data?: UpdateACLCommandOutput) => void): void;
    /**
     * <p>Modifies the settings for a cluster. You can use this operation to change one or more cluster configuration settings by specifying the settings and the new values.</p>
     */
    updateCluster(args: UpdateClusterCommandInput, options?: __HttpHandlerOptions): Promise<UpdateClusterCommandOutput>;
    updateCluster(args: UpdateClusterCommandInput, cb: (err: any, data?: UpdateClusterCommandOutput) => void): void;
    updateCluster(args: UpdateClusterCommandInput, options: __HttpHandlerOptions, cb: (err: any, data?: UpdateClusterCommandOutput) => void): void;
    /**
     * <p>Updates the parameters of a parameter group. You can modify up to 20 parameters in a single request by submitting a list parameter name and value pairs.</p>
     */
    updateParameterGroup(args: UpdateParameterGroupCommandInput, options?: __HttpHandlerOptions): Promise<UpdateParameterGroupCommandOutput>;
    updateParameterGroup(args: UpdateParameterGroupCommandInput, cb: (err: any, data?: UpdateParameterGroupCommandOutput) => void): void;
    updateParameterGroup(args: UpdateParameterGroupCommandInput, options: __HttpHandlerOptions, cb: (err: any, data?: UpdateParameterGroupCommandOutput) => void): void;
    /**
     * <p>Updates a subnet group. For more information, see <a href="https://docs.aws.amazon.com/MemoryDB/latest/devguide/ubnetGroups.Modifying.html">Updating a subnet group</a>
     *          </p>
     */
    updateSubnetGroup(args: UpdateSubnetGroupCommandInput, options?: __HttpHandlerOptions): Promise<UpdateSubnetGroupCommandOutput>;
    updateSubnetGroup(args: UpdateSubnetGroupCommandInput, cb: (err: any, data?: UpdateSubnetGroupCommandOutput) => void): void;
    updateSubnetGroup(args: UpdateSubnetGroupCommandInput, options: __HttpHandlerOptions, cb: (err: any, data?: UpdateSubnetGroupCommandOutput) => void): void;
    /**
     * <p>Changes user password(s) and/or access string.</p>
     */
    updateUser(args: UpdateUserCommandInput, options?: __HttpHandlerOptions): Promise<UpdateUserCommandOutput>;
    updateUser(args: UpdateUserCommandInput, cb: (err: any, data?: UpdateUserCommandOutput) => void): void;
    updateUser(args: UpdateUserCommandInput, options: __HttpHandlerOptions, cb: (err: any, data?: UpdateUserCommandOutput) => void): void;
}
