import { Command as $Command } from "@aws-sdk/smithy-client";
import { Handler, HttpHandlerOptions as __HttpHandlerOptions, MetadataBearer as __MetadataBearer, MiddlewareStack } from "@aws-sdk/types";
import { MemoryDBClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes } from "../MemoryDBClient";
import { DeleteACLRequest, DeleteACLResponse } from "../models/models_0";
export interface DeleteACLCommandInput extends DeleteACLRequest {
}
export interface DeleteACLCommandOutput extends DeleteACLResponse, __MetadataBearer {
}
/**
 * <p>Deletes an Access Control List. The ACL must first be disassociated from the cluster before it can be deleted. For more information, see <a href="https://docs.aws.amazon.com/MemoryDB/latest/devguide/clusters.acls.html">Authenticating users with Access Contol Lists (ACLs)</a>.</p>
 * @example
 * Use a bare-bones client and the command you need to make an API call.
 * ```javascript
 * import { MemoryDBClient, DeleteACLCommand } from "@aws-sdk/client-memorydb"; // ES Modules import
 * // const { MemoryDBClient, DeleteACLCommand } = require("@aws-sdk/client-memorydb"); // CommonJS import
 * const client = new MemoryDBClient(config);
 * const command = new DeleteACLCommand(input);
 * const response = await client.send(command);
 * ```
 *
 * @see {@link DeleteACLCommandInput} for command's `input` shape.
 * @see {@link DeleteACLCommandOutput} for command's `response` shape.
 * @see {@link MemoryDBClientResolvedConfig | config} for MemoryDBClient's `config` shape.
 *
 */
export declare class DeleteACLCommand extends $Command<DeleteACLCommandInput, DeleteACLCommandOutput, MemoryDBClientResolvedConfig> {
    readonly input: DeleteACLCommandInput;
    constructor(input: DeleteACLCommandInput);
    /**
     * @internal
     */
    resolveMiddleware(clientStack: MiddlewareStack<ServiceInputTypes, ServiceOutputTypes>, configuration: MemoryDBClientResolvedConfig, options?: __HttpHandlerOptions): Handler<DeleteACLCommandInput, DeleteACLCommandOutput>;
    private serialize;
    private deserialize;
}
