import { Command as $Command } from "@aws-sdk/smithy-client";
import { Handler, HttpHandlerOptions as __HttpHandlerOptions, MetadataBearer as __MetadataBearer, MiddlewareStack } from "@aws-sdk/types";
import { MemoryDBClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes } from "../MemoryDBClient";
import { DescribeEngineVersionsRequest, DescribeEngineVersionsResponse } from "../models/models_0";
export interface DescribeEngineVersionsCommandInput extends DescribeEngineVersionsRequest {
}
export interface DescribeEngineVersionsCommandOutput extends DescribeEngineVersionsResponse, __MetadataBearer {
}
/**
 * <p>Returns a list of the available Redis engine versions.</p>
 * @example
 * Use a bare-bones client and the command you need to make an API call.
 * ```javascript
 * import { MemoryDBClient, DescribeEngineVersionsCommand } from "@aws-sdk/client-memorydb"; // ES Modules import
 * // const { MemoryDBClient, DescribeEngineVersionsCommand } = require("@aws-sdk/client-memorydb"); // CommonJS import
 * const client = new MemoryDBClient(config);
 * const command = new DescribeEngineVersionsCommand(input);
 * const response = await client.send(command);
 * ```
 *
 * @see {@link DescribeEngineVersionsCommandInput} for command's `input` shape.
 * @see {@link DescribeEngineVersionsCommandOutput} for command's `response` shape.
 * @see {@link MemoryDBClientResolvedConfig | config} for MemoryDBClient's `config` shape.
 *
 */
export declare class DescribeEngineVersionsCommand extends $Command<DescribeEngineVersionsCommandInput, DescribeEngineVersionsCommandOutput, MemoryDBClientResolvedConfig> {
    readonly input: DescribeEngineVersionsCommandInput;
    constructor(input: DescribeEngineVersionsCommandInput);
    /**
     * @internal
     */
    resolveMiddleware(clientStack: MiddlewareStack<ServiceInputTypes, ServiceOutputTypes>, configuration: MemoryDBClientResolvedConfig, options?: __HttpHandlerOptions): Handler<DescribeEngineVersionsCommandInput, DescribeEngineVersionsCommandOutput>;
    private serialize;
    private deserialize;
}
