import { Command as $Command } from "@aws-sdk/smithy-client";
import { Handler, HttpHandlerOptions as __HttpHandlerOptions, MetadataBearer as __MetadataBearer, MiddlewareStack } from "@aws-sdk/types";
import { MemoryDBClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes } from "../MemoryDBClient";
import { FailoverShardRequest, FailoverShardResponse } from "../models/models_0";
export interface FailoverShardCommandInput extends FailoverShardRequest {
}
export interface FailoverShardCommandOutput extends FailoverShardResponse, __MetadataBearer {
}
/**
 * <p>Used to failover a shard</p>
 * @example
 * Use a bare-bones client and the command you need to make an API call.
 * ```javascript
 * import { MemoryDBClient, FailoverShardCommand } from "@aws-sdk/client-memorydb"; // ES Modules import
 * // const { MemoryDBClient, FailoverShardCommand } = require("@aws-sdk/client-memorydb"); // CommonJS import
 * const client = new MemoryDBClient(config);
 * const command = new FailoverShardCommand(input);
 * const response = await client.send(command);
 * ```
 *
 * @see {@link FailoverShardCommandInput} for command's `input` shape.
 * @see {@link FailoverShardCommandOutput} for command's `response` shape.
 * @see {@link MemoryDBClientResolvedConfig | config} for MemoryDBClient's `config` shape.
 *
 */
export declare class FailoverShardCommand extends $Command<FailoverShardCommandInput, FailoverShardCommandOutput, MemoryDBClientResolvedConfig> {
    readonly input: FailoverShardCommandInput;
    constructor(input: FailoverShardCommandInput);
    /**
     * @internal
     */
    resolveMiddleware(clientStack: MiddlewareStack<ServiceInputTypes, ServiceOutputTypes>, configuration: MemoryDBClientResolvedConfig, options?: __HttpHandlerOptions): Handler<FailoverShardCommandInput, FailoverShardCommandOutput>;
    private serialize;
    private deserialize;
}
