import { Command as $Command } from "@aws-sdk/smithy-client";
import { Handler, HttpHandlerOptions as __HttpHandlerOptions, MetadataBearer as __MetadataBearer, MiddlewareStack } from "@aws-sdk/types";
import { MemoryDBClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes } from "../MemoryDBClient";
import { ResetParameterGroupRequest, ResetParameterGroupResponse } from "../models/models_0";
export interface ResetParameterGroupCommandInput extends ResetParameterGroupRequest {
}
export interface ResetParameterGroupCommandOutput extends ResetParameterGroupResponse, __MetadataBearer {
}
/**
 * <p>Modifies the parameters of a parameter group to the engine or system default value. You can reset specific parameters by submitting a list of parameter names. To reset the entire parameter group, specify the AllParameters and ParameterGroupName parameters.</p>
 * @example
 * Use a bare-bones client and the command you need to make an API call.
 * ```javascript
 * import { MemoryDBClient, ResetParameterGroupCommand } from "@aws-sdk/client-memorydb"; // ES Modules import
 * // const { MemoryDBClient, ResetParameterGroupCommand } = require("@aws-sdk/client-memorydb"); // CommonJS import
 * const client = new MemoryDBClient(config);
 * const command = new ResetParameterGroupCommand(input);
 * const response = await client.send(command);
 * ```
 *
 * @see {@link ResetParameterGroupCommandInput} for command's `input` shape.
 * @see {@link ResetParameterGroupCommandOutput} for command's `response` shape.
 * @see {@link MemoryDBClientResolvedConfig | config} for MemoryDBClient's `config` shape.
 *
 */
export declare class ResetParameterGroupCommand extends $Command<ResetParameterGroupCommandInput, ResetParameterGroupCommandOutput, MemoryDBClientResolvedConfig> {
    readonly input: ResetParameterGroupCommandInput;
    constructor(input: ResetParameterGroupCommandInput);
    /**
     * @internal
     */
    resolveMiddleware(clientStack: MiddlewareStack<ServiceInputTypes, ServiceOutputTypes>, configuration: MemoryDBClientResolvedConfig, options?: __HttpHandlerOptions): Handler<ResetParameterGroupCommandInput, ResetParameterGroupCommandOutput>;
    private serialize;
    private deserialize;
}
