import { ExceptionOptionType as __ExceptionOptionType } from "@aws-sdk/smithy-client";
import { MemoryDBServiceException as __BaseException } from "./MemoryDBServiceException";
/**
 * <p>Returns the updates being applied to the ACL.</p>
 */
export interface ACLPendingChanges {
    /**
     * <p>A list of user names being removed from the ACL</p>
     */
    UserNamesToRemove?: string[];
    /**
     * <p>A list of users being added to the ACL</p>
     */
    UserNamesToAdd?: string[];
}
export declare namespace ACLPendingChanges {
    /**
     * @internal
     */
    const filterSensitiveLog: (obj: ACLPendingChanges) => any;
}
/**
 * <p>An Access Control List. You can authenticate users with Access Contol Lists.
 *
 *          ACLs enable you to control cluster access by grouping users. These Access control lists are designed as a way to organize access to clusters.</p>
 */
export interface ACL {
    /**
     * <p>The name of the Access Control List</p>
     */
    Name?: string;
    /**
     * <p>Indicates ACL status. Can be "creating", "active", "modifying", "deleting".</p>
     */
    Status?: string;
    /**
     * <p>The list of user names that belong to the ACL.</p>
     */
    UserNames?: string[];
    /**
     * <p>The minimum engine version supported for the ACL</p>
     */
    MinimumEngineVersion?: string;
    /**
     * <p>A list of updates being applied to the ACL.</p>
     */
    PendingChanges?: ACLPendingChanges;
    /**
     * <p>A list of clusters associated with the ACL.</p>
     */
    Clusters?: string[];
    /**
     * <p>The Amazon Resource Name (ARN) of the ACL</p>
     */
    ARN?: string;
}
export declare namespace ACL {
    /**
     * @internal
     */
    const filterSensitiveLog: (obj: ACL) => any;
}
/**
 * <p></p>
 */
export declare class ACLAlreadyExistsFault extends __BaseException {
    readonly name: "ACLAlreadyExistsFault";
    readonly $fault: "client";
    /**
     * @internal
     */
    constructor(opts: __ExceptionOptionType<ACLAlreadyExistsFault, __BaseException>);
}
/**
 * <p></p>
 */
export declare class ACLNotFoundFault extends __BaseException {
    readonly name: "ACLNotFoundFault";
    readonly $fault: "client";
    /**
     * @internal
     */
    constructor(opts: __ExceptionOptionType<ACLNotFoundFault, __BaseException>);
}
/**
 * <p></p>
 */
export declare class ACLQuotaExceededFault extends __BaseException {
    readonly name: "ACLQuotaExceededFault";
    readonly $fault: "client";
    /**
     * @internal
     */
    constructor(opts: __ExceptionOptionType<ACLQuotaExceededFault, __BaseException>);
}
/**
 * <p>The status of the ACL update</p>
 */
export interface ACLsUpdateStatus {
    /**
     * <p>A list of ACLs pending to be applied.</p>
     */
    ACLToApply?: string;
}
export declare namespace ACLsUpdateStatus {
    /**
     * @internal
     */
    const filterSensitiveLog: (obj: ACLsUpdateStatus) => any;
}
/**
 * <p>A request to apply a service update</p>
 */
export interface ServiceUpdateRequest {
    /**
     * <p>The unique ID of the service update</p>
     */
    ServiceUpdateNameToApply?: string;
}
export declare namespace ServiceUpdateRequest {
    /**
     * @internal
     */
    const filterSensitiveLog: (obj: ServiceUpdateRequest) => any;
}
export interface BatchUpdateClusterRequest {
    /**
     * <p>The cluster names to apply the updates.</p>
     */
    ClusterNames: string[] | undefined;
    /**
     * <p>The unique ID of the service update</p>
     */
    ServiceUpdate?: ServiceUpdateRequest;
}
export declare namespace BatchUpdateClusterRequest {
    /**
     * @internal
     */
    const filterSensitiveLog: (obj: BatchUpdateClusterRequest) => any;
}
export declare enum AZStatus {
    MultiAZ = "multiaz",
    SingleAZ = "singleaz"
}
/**
 * <p>Represents the information required for client programs to connect to the cluster and its nodes.</p>
 */
export interface Endpoint {
    /**
     * <p>The DNS hostname of the node.</p>
     */
    Address?: string;
    /**
     * <p>The port number that the engine is listening on.</p>
     */
    Port?: number;
}
export declare namespace Endpoint {
    /**
     * @internal
     */
    const filterSensitiveLog: (obj: Endpoint) => any;
}
/**
 * <p>Represents the progress of an online resharding operation.</p>
 */
export interface SlotMigration {
    /**
     * <p>The percentage of the slot migration that is complete.</p>
     */
    ProgressPercentage?: number;
}
export declare namespace SlotMigration {
    /**
     * @internal
     */
    const filterSensitiveLog: (obj: SlotMigration) => any;
}
/**
 * <p>The status of the online resharding</p>
 */
export interface ReshardingStatus {
    /**
     * <p>The status of the online resharding slot migration</p>
     */
    SlotMigration?: SlotMigration;
}
export declare namespace ReshardingStatus {
    /**
     * @internal
     */
    const filterSensitiveLog: (obj: ReshardingStatus) => any;
}
export declare enum ServiceUpdateStatus {
    COMPLETE = "complete",
    IN_PROGRESS = "in-progress",
    NOT_APPLIED = "available",
    SCHEDULED = "scheduled"
}
/**
 * <p>Update action that has yet to be processed for the corresponding apply/stop request</p>
 */
export interface PendingModifiedServiceUpdate {
    /**
     * <p>The unique ID of the service update</p>
     */
    ServiceUpdateName?: string;
    /**
     * <p>The status of the service update</p>
     */
    Status?: ServiceUpdateStatus | string;
}
export declare namespace PendingModifiedServiceUpdate {
    /**
     * @internal
     */
    const filterSensitiveLog: (obj: PendingModifiedServiceUpdate) => any;
}
/**
 * <p>A list of updates being applied to the cluster</p>
 */
export interface ClusterPendingUpdates {
    /**
     * <p>The status of an online resharding operation.</p>
     */
    Resharding?: ReshardingStatus;
    /**
     * <p>A list of ACLs associated with the cluster that are being updated</p>
     */
    ACLs?: ACLsUpdateStatus;
    /**
     * <p>A list of service updates being applied to the cluster</p>
     */
    ServiceUpdates?: PendingModifiedServiceUpdate[];
}
export declare namespace ClusterPendingUpdates {
    /**
     * @internal
     */
    const filterSensitiveLog: (obj: ClusterPendingUpdates) => any;
}
/**
 * <p>Represents a single security group and its status.</p>
 */
export interface SecurityGroupMembership {
    /**
     * <p>The identifier of the security group.</p>
     */
    SecurityGroupId?: string;
    /**
     * <p>The status of the security group membership. The status changes whenever a security group is modified, or when the security groups assigned to a cluster are modified.</p>
     */
    Status?: string;
}
export declare namespace SecurityGroupMembership {
    /**
     * @internal
     */
    const filterSensitiveLog: (obj: SecurityGroupMembership) => any;
}
/**
 * <p>Represents an individual node within a cluster. Each node runs its own instance of the cluster's protocol-compliant caching software.</p>
 */
export interface Node {
    /**
     * <p>The  node identifier. A node name is a numeric identifier (0001, 0002, etc.). The combination of cluster name, shard name and node name uniquely identifies every node used in a customer's Amazon account.</p>
     */
    Name?: string;
    /**
     * <p>The status of the service update on the node</p>
     */
    Status?: string;
    /**
     * <p>The Availability Zone in which the node resides</p>
     */
    AvailabilityZone?: string;
    /**
     * <p>The date and time when the node was created.</p>
     */
    CreateTime?: Date;
    /**
     * <p>The hostname for connecting to this node.</p>
     */
    Endpoint?: Endpoint;
}
export declare namespace Node {
    /**
     * @internal
     */
    const filterSensitiveLog: (obj: Node) => any;
}
/**
 * <p>Represents a collection of nodes in a cluster. One node in the node group is the read/write primary node. All the other nodes are read-only Replica nodes.</p>
 */
export interface Shard {
    /**
     * <p>The name of the shard</p>
     */
    Name?: string;
    /**
     * <p>The current state of this replication group - creating, available, modifying, deleting.</p>
     */
    Status?: string;
    /**
     * <p>The keyspace for this shard.</p>
     */
    Slots?: string;
    /**
     * <p>A list containing information about individual nodes within the shard</p>
     */
    Nodes?: Node[];
    /**
     * <p>The number of nodes in the shard</p>
     */
    NumberOfNodes?: number;
}
export declare namespace Shard {
    /**
     * @internal
     */
    const filterSensitiveLog: (obj: Shard) => any;
}
/**
 * <p>Contains all of the attributes of a specific cluster.</p>
 */
export interface Cluster {
    /**
     * <p>The user-supplied name of the cluster. This identifier is a unique key that identifies a cluster.</p>
     */
    Name?: string;
    /**
     * <p>A description of the cluster</p>
     */
    Description?: string;
    /**
     * <p>The status of the cluster. For example, Available, Updating, Creating.</p>
     */
    Status?: string;
    /**
     * <p>A group of settings that are currently being applied.</p>
     */
    PendingUpdates?: ClusterPendingUpdates;
    /**
     * <p>The number of shards in the cluster</p>
     */
    NumberOfShards?: number;
    /**
     * <p>A list of shards that are members of the cluster.</p>
     */
    Shards?: Shard[];
    /**
     * <p>Indicates if the cluster has a Multi-AZ configuration (multiaz) or not (singleaz).</p>
     */
    AvailabilityMode?: AZStatus | string;
    /**
     * <p>The cluster's configuration endpoint</p>
     */
    ClusterEndpoint?: Endpoint;
    /**
     * <p>The cluster's node type</p>
     */
    NodeType?: string;
    /**
     * <p>The Redis engine version used by the cluster</p>
     */
    EngineVersion?: string;
    /**
     * <p>The Redis engine patch version used by the cluster</p>
     */
    EnginePatchVersion?: string;
    /**
     * <p>The name of the parameter group used by the cluster</p>
     */
    ParameterGroupName?: string;
    /**
     * <p>The status of the parameter group used by the cluster, for example 'active' or 'applying'.</p>
     */
    ParameterGroupStatus?: string;
    /**
     * <p>A list of security groups used by the cluster</p>
     */
    SecurityGroups?: SecurityGroupMembership[];
    /**
     * <p>The name of the subnet group used by the cluster</p>
     */
    SubnetGroupName?: string;
    /**
     * <p>A flag to indicate if In-transit encryption is enabled</p>
     */
    TLSEnabled?: boolean;
    /**
     * <p>The ID of the KMS key used to encrypt the cluster</p>
     */
    KmsKeyId?: string;
    /**
     * <p>The Amazon Resource Name (ARN) of the cluster.</p>
     */
    ARN?: string;
    /**
     * <p>The Amazon Resource Name (ARN) of the SNS notification topic</p>
     */
    SnsTopicArn?: string;
    /**
     * <p>The SNS topic must be in Active status to receive notifications</p>
     */
    SnsTopicStatus?: string;
    /**
     * <p>The number of days for which MemoryDB retains automatic snapshots before deleting them. For example, if you set SnapshotRetentionLimit to 5, a snapshot that was taken today is retained for 5 days before being deleted.</p>
     */
    SnapshotRetentionLimit?: number;
    /**
     * <p>Specifies the weekly time range during which maintenance on the cluster is performed. It is specified as a range in the format ddd:hh24:mi-ddd:hh24:mi (24H Clock UTC). The minimum maintenance window is a 60 minute period. </p>
     */
    MaintenanceWindow?: string;
    /**
     * <p>The daily time range (in UTC) during which MemoryDB begins taking a daily snapshot of your shard.
     *
     *          Example: 05:00-09:00
     *
     *          If you do not specify this parameter, MemoryDB automatically chooses an appropriate time range.</p>
     */
    SnapshotWindow?: string;
    /**
     * <p>The name of the Access Control List associated with this cluster.</p>
     */
    ACLName?: string;
    /**
     * <p>When set to true, the cluster will automatically receive minor engine version upgrades after launch.</p>
     */
    AutoMinorVersionUpgrade?: boolean;
}
export declare namespace Cluster {
    /**
     * @internal
     */
    const filterSensitiveLog: (obj: Cluster) => any;
}
/**
 * <p>A cluster whose updates have failed</p>
 */
export interface UnprocessedCluster {
    /**
     * <p>The name of the cluster</p>
     */
    ClusterName?: string;
    /**
     * <p>The error type associated with the update failure</p>
     */
    ErrorType?: string;
    /**
     * <p>The error message associated with the update failure</p>
     */
    ErrorMessage?: string;
}
export declare namespace UnprocessedCluster {
    /**
     * @internal
     */
    const filterSensitiveLog: (obj: UnprocessedCluster) => any;
}
export interface BatchUpdateClusterResponse {
    /**
     * <p>The list of clusters that have been updated.</p>
     */
    ProcessedClusters?: Cluster[];
    /**
     * <p>The list of clusters where updates have not been applied.</p>
     */
    UnprocessedClusters?: UnprocessedCluster[];
}
export declare namespace BatchUpdateClusterResponse {
    /**
     * @internal
     */
    const filterSensitiveLog: (obj: BatchUpdateClusterResponse) => any;
}
/**
 * <p></p>
 */
export declare class InvalidParameterValueException extends __BaseException {
    readonly name: "InvalidParameterValueException";
    readonly $fault: "client";
    /**
     * @internal
     */
    constructor(opts: __ExceptionOptionType<InvalidParameterValueException, __BaseException>);
}
/**
 * <p></p>
 */
export declare class ServiceUpdateNotFoundFault extends __BaseException {
    readonly name: "ServiceUpdateNotFoundFault";
    readonly $fault: "client";
    /**
     * @internal
     */
    constructor(opts: __ExceptionOptionType<ServiceUpdateNotFoundFault, __BaseException>);
}
/**
 * <p>A tag that can be added to an MemoryDB resource. Tags are composed of a Key/Value pair. You can use tags to categorize and track all your MemoryDB resources.
 *          When you add or remove tags on clusters, those actions will be replicated to all nodes in the cluster. A tag with a null Value is permitted. For more information, see
 *          <a href="https://docs.aws.amazon.com/MemoryDB/latest/devguide/tagging-resources.html">Tagging your MemoryDB resources</a>
 *          </p>
 */
export interface Tag {
    /**
     * <p>The key for the tag. May not be null.</p>
     */
    Key?: string;
    /**
     * <p>The tag's value. May be null.</p>
     */
    Value?: string;
}
export declare namespace Tag {
    /**
     * @internal
     */
    const filterSensitiveLog: (obj: Tag) => any;
}
export interface CopySnapshotRequest {
    /**
     * <p>The name of an existing snapshot from which to make a copy.</p>
     */
    SourceSnapshotName: string | undefined;
    /**
     * <p>A name for the snapshot copy. MemoryDB does not permit overwriting a snapshot, therefore this name must be unique within its context - MemoryDB or an Amazon S3 bucket if exporting.</p>
     */
    TargetSnapshotName: string | undefined;
    /**
     * <p>The Amazon S3 bucket to which the snapshot is exported. This parameter is used only when exporting a snapshot for external access.
     *
     *        When using this parameter to export a snapshot, be sure MemoryDB has the needed permissions to this S3 bucket. For more information, see
     *
     *        <a href="https://docs.aws.amazon.com/MemoryDB/latest/devguide/snapshots-exporting.html">Step 2: Grant MemoryDB Access to Your Amazon S3 Bucket</a>.
     *
     *      </p>
     */
    TargetBucket?: string;
    /**
     * <p>The ID of the KMS key used to encrypt the target snapshot.</p>
     */
    KmsKeyId?: string;
    /**
     * <p>A list of tags to be added to this resource. A tag is a key-value pair. A tag key must be accompanied by a tag value, although null is accepted.</p>
     */
    Tags?: Tag[];
}
export declare namespace CopySnapshotRequest {
    /**
     * @internal
     */
    const filterSensitiveLog: (obj: CopySnapshotRequest) => any;
}
/**
 * <p>Shard configuration options. Each shard configuration has the following: Slots and ReplicaCount.</p>
 */
export interface ShardConfiguration {
    /**
     * <p>A string that specifies the keyspace for a particular node group. Keyspaces range from 0 to 16,383. The string is in the format startkey-endkey.</p>
     */
    Slots?: string;
    /**
     * <p>The number of read replica nodes in this shard.</p>
     */
    ReplicaCount?: number;
}
export declare namespace ShardConfiguration {
    /**
     * @internal
     */
    const filterSensitiveLog: (obj: ShardConfiguration) => any;
}
/**
 * <p>Provides details of a shard in a snapshot</p>
 */
export interface ShardDetail {
    /**
     * <p>The name of the shard</p>
     */
    Name?: string;
    /**
     * <p>The configuration details of the shard</p>
     */
    Configuration?: ShardConfiguration;
    /**
     * <p>The size of the shard's snapshot</p>
     */
    Size?: string;
    /**
     * <p>The date and time that the shard's snapshot was created</p>
     */
    SnapshotCreationTime?: Date;
}
export declare namespace ShardDetail {
    /**
     * @internal
     */
    const filterSensitiveLog: (obj: ShardDetail) => any;
}
/**
 * <p>A list of cluster configuration options. </p>
 */
export interface ClusterConfiguration {
    /**
     * <p>The name of the cluster</p>
     */
    Name?: string;
    /**
     * <p>The description of the cluster configuration</p>
     */
    Description?: string;
    /**
     * <p>The node type used for the cluster</p>
     */
    NodeType?: string;
    /**
     * <p>The Redis engine version used by the cluster</p>
     */
    EngineVersion?: string;
    /**
     * <p>The specified maintenance window for the cluster</p>
     */
    MaintenanceWindow?: string;
    /**
     * <p>The Amazon Resource Name (ARN) of the SNS notification topic for the cluster</p>
     */
    TopicArn?: string;
    /**
     * <p>The port used by the cluster</p>
     */
    Port?: number;
    /**
     * <p>The name of parameter group used by the cluster</p>
     */
    ParameterGroupName?: string;
    /**
     * <p>The name of the subnet group used by the cluster</p>
     */
    SubnetGroupName?: string;
    /**
     * <p>The ID of the VPC the cluster belongs to</p>
     */
    VpcId?: string;
    /**
     * <p>The snapshot retention limit set by the cluster</p>
     */
    SnapshotRetentionLimit?: number;
    /**
     * <p>The snapshot window set by the cluster</p>
     */
    SnapshotWindow?: string;
    /**
     * <p>The number of shards in the cluster</p>
     */
    NumShards?: number;
    /**
     * <p>The list of shards in the cluster</p>
     */
    Shards?: ShardDetail[];
}
export declare namespace ClusterConfiguration {
    /**
     * @internal
     */
    const filterSensitiveLog: (obj: ClusterConfiguration) => any;
}
/**
 * <p>Represents a copy of an entire cluster as of the time when the snapshot was taken.</p>
 */
export interface Snapshot {
    /**
     * <p>The name of the snapshot</p>
     */
    Name?: string;
    /**
     * <p>The status of the snapshot. Valid values: creating | available | restoring | copying | deleting.</p>
     */
    Status?: string;
    /**
     * <p>Indicates whether the snapshot is from an automatic backup (automated) or was created manually (manual).</p>
     */
    Source?: string;
    /**
     * <p>The ID of the KMS key used to encrypt the snapshot.</p>
     */
    KmsKeyId?: string;
    /**
     * <p>The ARN (Amazon Resource Name) of the snapshot.</p>
     */
    ARN?: string;
    /**
     * <p>The configuration of the cluster from which the snapshot was taken</p>
     */
    ClusterConfiguration?: ClusterConfiguration;
}
export declare namespace Snapshot {
    /**
     * @internal
     */
    const filterSensitiveLog: (obj: Snapshot) => any;
}
export interface CopySnapshotResponse {
    /**
     * <p>Represents a copy of an entire cluster as of the time when the snapshot was taken.</p>
     */
    Snapshot?: Snapshot;
}
export declare namespace CopySnapshotResponse {
    /**
     * @internal
     */
    const filterSensitiveLog: (obj: CopySnapshotResponse) => any;
}
/**
 * <p></p>
 */
export declare class InvalidParameterCombinationException extends __BaseException {
    readonly name: "InvalidParameterCombinationException";
    readonly $fault: "client";
    /**
     * @internal
     */
    constructor(opts: __ExceptionOptionType<InvalidParameterCombinationException, __BaseException>);
}
/**
 * <p></p>
 */
export declare class InvalidSnapshotStateFault extends __BaseException {
    readonly name: "InvalidSnapshotStateFault";
    readonly $fault: "client";
    /**
     * @internal
     */
    constructor(opts: __ExceptionOptionType<InvalidSnapshotStateFault, __BaseException>);
}
/**
 * <p></p>
 */
export declare class ServiceLinkedRoleNotFoundFault extends __BaseException {
    readonly name: "ServiceLinkedRoleNotFoundFault";
    readonly $fault: "client";
    /**
     * @internal
     */
    constructor(opts: __ExceptionOptionType<ServiceLinkedRoleNotFoundFault, __BaseException>);
}
/**
 * <p></p>
 */
export declare class SnapshotAlreadyExistsFault extends __BaseException {
    readonly name: "SnapshotAlreadyExistsFault";
    readonly $fault: "client";
    /**
     * @internal
     */
    constructor(opts: __ExceptionOptionType<SnapshotAlreadyExistsFault, __BaseException>);
}
/**
 * <p></p>
 */
export declare class SnapshotNotFoundFault extends __BaseException {
    readonly name: "SnapshotNotFoundFault";
    readonly $fault: "client";
    /**
     * @internal
     */
    constructor(opts: __ExceptionOptionType<SnapshotNotFoundFault, __BaseException>);
}
/**
 * <p></p>
 */
export declare class SnapshotQuotaExceededFault extends __BaseException {
    readonly name: "SnapshotQuotaExceededFault";
    readonly $fault: "client";
    /**
     * @internal
     */
    constructor(opts: __ExceptionOptionType<SnapshotQuotaExceededFault, __BaseException>);
}
/**
 * <p></p>
 */
export declare class TagQuotaPerResourceExceeded extends __BaseException {
    readonly name: "TagQuotaPerResourceExceeded";
    readonly $fault: "client";
    /**
     * @internal
     */
    constructor(opts: __ExceptionOptionType<TagQuotaPerResourceExceeded, __BaseException>);
}
export interface CreateACLRequest {
    /**
     * <p>The name of the Access Control List.</p>
     */
    ACLName: string | undefined;
    /**
     * <p>The list of users that belong to the Access Control List.</p>
     */
    UserNames?: string[];
    /**
     * <p>A list of tags to be added to this resource. A tag is a key-value pair. A tag key must be accompanied by a tag value, although null is accepted.</p>
     */
    Tags?: Tag[];
}
export declare namespace CreateACLRequest {
    /**
     * @internal
     */
    const filterSensitiveLog: (obj: CreateACLRequest) => any;
}
export interface CreateACLResponse {
    /**
     * <p>The newly-created Access Control List.</p>
     */
    ACL?: ACL;
}
export declare namespace CreateACLResponse {
    /**
     * @internal
     */
    const filterSensitiveLog: (obj: CreateACLResponse) => any;
}
/**
 * <p></p>
 */
export declare class DefaultUserRequired extends __BaseException {
    readonly name: "DefaultUserRequired";
    readonly $fault: "client";
    /**
     * @internal
     */
    constructor(opts: __ExceptionOptionType<DefaultUserRequired, __BaseException>);
}
/**
 * <p></p>
 */
export declare class DuplicateUserNameFault extends __BaseException {
    readonly name: "DuplicateUserNameFault";
    readonly $fault: "client";
    /**
     * @internal
     */
    constructor(opts: __ExceptionOptionType<DuplicateUserNameFault, __BaseException>);
}
/**
 * <p></p>
 */
export declare class UserNotFoundFault extends __BaseException {
    readonly name: "UserNotFoundFault";
    readonly $fault: "client";
    /**
     * @internal
     */
    constructor(opts: __ExceptionOptionType<UserNotFoundFault, __BaseException>);
}
/**
 * <p></p>
 */
export declare class ClusterAlreadyExistsFault extends __BaseException {
    readonly name: "ClusterAlreadyExistsFault";
    readonly $fault: "client";
    /**
     * @internal
     */
    constructor(opts: __ExceptionOptionType<ClusterAlreadyExistsFault, __BaseException>);
}
/**
 * <p></p>
 */
export declare class ClusterQuotaForCustomerExceededFault extends __BaseException {
    readonly name: "ClusterQuotaForCustomerExceededFault";
    readonly $fault: "client";
    /**
     * @internal
     */
    constructor(opts: __ExceptionOptionType<ClusterQuotaForCustomerExceededFault, __BaseException>);
}
export interface CreateClusterRequest {
    /**
     * <p>The name of the cluster. This value must be unique as it also serves as the cluster identifier.</p>
     */
    ClusterName: string | undefined;
    /**
     * <p>The compute and memory capacity of the nodes in the cluster.</p>
     */
    NodeType: string | undefined;
    /**
     * <p>The name of the parameter group associated with the cluster.</p>
     */
    ParameterGroupName?: string;
    /**
     * <p>An optional description of the cluster.</p>
     */
    Description?: string;
    /**
     * <p>The number of shards the cluster will contain. The default value is 1. </p>
     */
    NumShards?: number;
    /**
     * <p>The number of replicas to apply to each shard. The default value is 1. The maximum is 5. </p>
     */
    NumReplicasPerShard?: number;
    /**
     * <p>The name of the subnet group to be used for the cluster.</p>
     */
    SubnetGroupName?: string;
    /**
     * <p>A list of security group names to associate with this cluster.</p>
     */
    SecurityGroupIds?: string[];
    /**
     * <p>Specifies the weekly time range during which maintenance on the cluster is performed. It is specified as a range in the format <code>ddd:hh24:mi-ddd:hh24:mi</code> (24H Clock UTC). The minimum maintenance window is a 60 minute period.</p>
     */
    MaintenanceWindow?: string;
    /**
     * <p>The port number on which each of the nodes accepts connections.</p>
     */
    Port?: number;
    /**
     * <p>The Amazon Resource Name (ARN) of the Amazon Simple Notification Service (SNS) topic to which notifications are sent.</p>
     */
    SnsTopicArn?: string;
    /**
     * <p>A flag to enable in-transit encryption on the cluster.</p>
     */
    TLSEnabled?: boolean;
    /**
     * <p>The ID of the KMS key used to encrypt the cluster.</p>
     */
    KmsKeyId?: string;
    /**
     * <p>A list of Amazon Resource Names (ARN) that uniquely identify the RDB snapshot files stored in Amazon S3. The snapshot files are used to populate the new cluster. The Amazon S3 object name in the ARN cannot contain any commas.</p>
     */
    SnapshotArns?: string[];
    /**
     * <p>The name of a snapshot from which to restore data into the new cluster. The snapshot status changes to restoring while the new cluster is being created.</p>
     */
    SnapshotName?: string;
    /**
     * <p>The number of days for which MemoryDB retains automatic snapshots before deleting them. For example, if you set SnapshotRetentionLimit to 5, a snapshot that was taken today is retained for 5 days before being deleted.</p>
     */
    SnapshotRetentionLimit?: number;
    /**
     * <p>A list of tags to be added to this resource. Tags are comma-separated key,value pairs (e.g. Key=myKey, Value=myKeyValue. You can include multiple tags as shown following: Key=myKey, Value=myKeyValue Key=mySecondKey, Value=mySecondKeyValue.</p>
     */
    Tags?: Tag[];
    /**
     * <p>The daily time range (in UTC) during which MemoryDB begins taking a daily snapshot of your shard.</p>
     *
     *          <p>    Example: 05:00-09:00</p>
     *
     *          <p>    If you do not specify this parameter, MemoryDB automatically chooses an appropriate time range.</p>
     */
    SnapshotWindow?: string;
    /**
     * <p>The name of the Access Control List to associate with the cluster.</p>
     */
    ACLName: string | undefined;
    /**
     * <p>The version number of the Redis engine to be used for the cluster.</p>
     */
    EngineVersion?: string;
    /**
     * <p>When set to true, the cluster will automatically receive minor engine version upgrades after launch.</p>
     */
    AutoMinorVersionUpgrade?: boolean;
}
export declare namespace CreateClusterRequest {
    /**
     * @internal
     */
    const filterSensitiveLog: (obj: CreateClusterRequest) => any;
}
export interface CreateClusterResponse {
    /**
     * <p>The newly-created cluster.</p>
     */
    Cluster?: Cluster;
}
export declare namespace CreateClusterResponse {
    /**
     * @internal
     */
    const filterSensitiveLog: (obj: CreateClusterResponse) => any;
}
/**
 * <p></p>
 */
export declare class InsufficientClusterCapacityFault extends __BaseException {
    readonly name: "InsufficientClusterCapacityFault";
    readonly $fault: "client";
    /**
     * @internal
     */
    constructor(opts: __ExceptionOptionType<InsufficientClusterCapacityFault, __BaseException>);
}
/**
 * <p></p>
 */
export declare class InvalidACLStateFault extends __BaseException {
    readonly name: "InvalidACLStateFault";
    readonly $fault: "client";
    /**
     * @internal
     */
    constructor(opts: __ExceptionOptionType<InvalidACLStateFault, __BaseException>);
}
/**
 * <p></p>
 */
export declare class InvalidCredentialsException extends __BaseException {
    readonly name: "InvalidCredentialsException";
    readonly $fault: "client";
    /**
     * @internal
     */
    constructor(opts: __ExceptionOptionType<InvalidCredentialsException, __BaseException>);
}
/**
 * <p></p>
 */
export declare class InvalidVPCNetworkStateFault extends __BaseException {
    readonly name: "InvalidVPCNetworkStateFault";
    readonly $fault: "client";
    /**
     * @internal
     */
    constructor(opts: __ExceptionOptionType<InvalidVPCNetworkStateFault, __BaseException>);
}
/**
 * <p></p>
 */
export declare class NodeQuotaForClusterExceededFault extends __BaseException {
    readonly name: "NodeQuotaForClusterExceededFault";
    readonly $fault: "client";
    /**
     * @internal
     */
    constructor(opts: __ExceptionOptionType<NodeQuotaForClusterExceededFault, __BaseException>);
}
/**
 * <p></p>
 */
export declare class NodeQuotaForCustomerExceededFault extends __BaseException {
    readonly name: "NodeQuotaForCustomerExceededFault";
    readonly $fault: "client";
    /**
     * @internal
     */
    constructor(opts: __ExceptionOptionType<NodeQuotaForCustomerExceededFault, __BaseException>);
}
/**
 * <p></p>
 */
export declare class ParameterGroupNotFoundFault extends __BaseException {
    readonly name: "ParameterGroupNotFoundFault";
    readonly $fault: "client";
    /**
     * @internal
     */
    constructor(opts: __ExceptionOptionType<ParameterGroupNotFoundFault, __BaseException>);
}
/**
 * <p></p>
 */
export declare class ShardsPerClusterQuotaExceededFault extends __BaseException {
    readonly name: "ShardsPerClusterQuotaExceededFault";
    readonly $fault: "client";
    /**
     * @internal
     */
    constructor(opts: __ExceptionOptionType<ShardsPerClusterQuotaExceededFault, __BaseException>);
}
/**
 * <p></p>
 */
export declare class SubnetGroupNotFoundFault extends __BaseException {
    readonly name: "SubnetGroupNotFoundFault";
    readonly $fault: "client";
    /**
     * @internal
     */
    constructor(opts: __ExceptionOptionType<SubnetGroupNotFoundFault, __BaseException>);
}
export interface CreateParameterGroupRequest {
    /**
     * <p>The name of the parameter group.</p>
     */
    ParameterGroupName: string | undefined;
    /**
     * <p>The name of the parameter group family that the parameter group can be used with.</p>
     */
    Family: string | undefined;
    /**
     * <p>An optional description of the parameter group.</p>
     */
    Description?: string;
    /**
     * <p>A list of tags to be added to this resource. A tag is a key-value pair. A tag key must be accompanied by a tag value, although null is accepted.</p>
     */
    Tags?: Tag[];
}
export declare namespace CreateParameterGroupRequest {
    /**
     * @internal
     */
    const filterSensitiveLog: (obj: CreateParameterGroupRequest) => any;
}
/**
 * <p>Represents the output of a CreateParameterGroup operation. A parameter group represents a combination of specific values for the parameters that are passed to the engine software during startup.</p>
 */
export interface ParameterGroup {
    /**
     * <p>The name of the parameter group</p>
     */
    Name?: string;
    /**
     * <p>The name of the parameter group family that this  parameter group is compatible with.</p>
     */
    Family?: string;
    /**
     * <p>A description of the parameter group</p>
     */
    Description?: string;
    /**
     * <p>The Amazon Resource Name (ARN) of the parameter group</p>
     */
    ARN?: string;
}
export declare namespace ParameterGroup {
    /**
     * @internal
     */
    const filterSensitiveLog: (obj: ParameterGroup) => any;
}
export interface CreateParameterGroupResponse {
    /**
     * <p>The newly-created parameter group.</p>
     */
    ParameterGroup?: ParameterGroup;
}
export declare namespace CreateParameterGroupResponse {
    /**
     * @internal
     */
    const filterSensitiveLog: (obj: CreateParameterGroupResponse) => any;
}
/**
 * <p></p>
 */
export declare class InvalidParameterGroupStateFault extends __BaseException {
    readonly name: "InvalidParameterGroupStateFault";
    readonly $fault: "client";
    /**
     * @internal
     */
    constructor(opts: __ExceptionOptionType<InvalidParameterGroupStateFault, __BaseException>);
}
/**
 * <p></p>
 */
export declare class ParameterGroupAlreadyExistsFault extends __BaseException {
    readonly name: "ParameterGroupAlreadyExistsFault";
    readonly $fault: "client";
    /**
     * @internal
     */
    constructor(opts: __ExceptionOptionType<ParameterGroupAlreadyExistsFault, __BaseException>);
}
/**
 * <p></p>
 */
export declare class ParameterGroupQuotaExceededFault extends __BaseException {
    readonly name: "ParameterGroupQuotaExceededFault";
    readonly $fault: "client";
    /**
     * @internal
     */
    constructor(opts: __ExceptionOptionType<ParameterGroupQuotaExceededFault, __BaseException>);
}
/**
 * <p></p>
 */
export declare class ClusterNotFoundFault extends __BaseException {
    readonly name: "ClusterNotFoundFault";
    readonly $fault: "client";
    /**
     * @internal
     */
    constructor(opts: __ExceptionOptionType<ClusterNotFoundFault, __BaseException>);
}
export interface CreateSnapshotRequest {
    /**
     * <p>The snapshot is created from this cluster.</p>
     */
    ClusterName: string | undefined;
    /**
     * <p>A name for the snapshot being created.</p>
     */
    SnapshotName: string | undefined;
    /**
     * <p>The ID of the KMS key used to encrypt the snapshot.</p>
     */
    KmsKeyId?: string;
    /**
     * <p>A list of tags to be added to this resource. A tag is a key-value pair. A tag key must be accompanied by a tag value, although null is accepted.</p>
     */
    Tags?: Tag[];
}
export declare namespace CreateSnapshotRequest {
    /**
     * @internal
     */
    const filterSensitiveLog: (obj: CreateSnapshotRequest) => any;
}
export interface CreateSnapshotResponse {
    /**
     * <p>The newly-created snapshot.</p>
     */
    Snapshot?: Snapshot;
}
export declare namespace CreateSnapshotResponse {
    /**
     * @internal
     */
    const filterSensitiveLog: (obj: CreateSnapshotResponse) => any;
}
/**
 * <p></p>
 */
export declare class InvalidClusterStateFault extends __BaseException {
    readonly name: "InvalidClusterStateFault";
    readonly $fault: "client";
    /**
     * @internal
     */
    constructor(opts: __ExceptionOptionType<InvalidClusterStateFault, __BaseException>);
}
export interface CreateSubnetGroupRequest {
    /**
     * <p>The name of the subnet group.</p>
     */
    SubnetGroupName: string | undefined;
    /**
     * <p>A description for the subnet group.</p>
     */
    Description?: string;
    /**
     * <p>A list of VPC subnet IDs for the subnet group.</p>
     */
    SubnetIds: string[] | undefined;
    /**
     * <p>A list of tags to be added to this resource. A tag is a key-value pair. A tag key must be accompanied by a tag value, although null is accepted.</p>
     */
    Tags?: Tag[];
}
export declare namespace CreateSubnetGroupRequest {
    /**
     * @internal
     */
    const filterSensitiveLog: (obj: CreateSubnetGroupRequest) => any;
}
/**
 * <p>Indicates if the cluster has a Multi-AZ configuration (multiaz) or not (singleaz).</p>
 */
export interface AvailabilityZone {
    /**
     * <p>The name of the Availability Zone.</p>
     */
    Name?: string;
}
export declare namespace AvailabilityZone {
    /**
     * @internal
     */
    const filterSensitiveLog: (obj: AvailabilityZone) => any;
}
/**
 * <p>Represents the subnet associated with a cluster. This parameter refers to subnets defined in Amazon Virtual Private Cloud (Amazon VPC) and used with MemoryDB.</p>
 */
export interface Subnet {
    /**
     * <p>The unique identifier for the subnet.</p>
     */
    Identifier?: string;
    /**
     * <p>The Availability Zone where the subnet resides</p>
     */
    AvailabilityZone?: AvailabilityZone;
}
export declare namespace Subnet {
    /**
     * @internal
     */
    const filterSensitiveLog: (obj: Subnet) => any;
}
/**
 * <p>Represents the output of one of the following operations:</p>
 *          <ul>
 *             <li>
 *                <p>CreateSubnetGroup</p>
 *             </li>
 *             <li>
 *                <p>UpdateSubnetGroup</p>
 *             </li>
 *          </ul>
 *          <p>A subnet group is a collection of subnets (typically private) that you can designate for your clusters running in an Amazon Virtual Private Cloud (VPC) environment.</p>
 */
export interface SubnetGroup {
    /**
     * <p>The name of the subnet group</p>
     */
    Name?: string;
    /**
     * <p>A description of the subnet group</p>
     */
    Description?: string;
    /**
     * <p>The Amazon Virtual Private Cloud identifier (VPC ID) of the subnet group.</p>
     */
    VpcId?: string;
    /**
     * <p>A list of subnets associated with the subnet group.</p>
     */
    Subnets?: Subnet[];
    /**
     * <p>The ARN (Amazon Resource Name) of the subnet group.</p>
     */
    ARN?: string;
}
export declare namespace SubnetGroup {
    /**
     * @internal
     */
    const filterSensitiveLog: (obj: SubnetGroup) => any;
}
export interface CreateSubnetGroupResponse {
    /**
     * <p>The newly-created subnet group</p>
     */
    SubnetGroup?: SubnetGroup;
}
export declare namespace CreateSubnetGroupResponse {
    /**
     * @internal
     */
    const filterSensitiveLog: (obj: CreateSubnetGroupResponse) => any;
}
/**
 * <p></p>
 */
export declare class InvalidSubnet extends __BaseException {
    readonly name: "InvalidSubnet";
    readonly $fault: "client";
    /**
     * @internal
     */
    constructor(opts: __ExceptionOptionType<InvalidSubnet, __BaseException>);
}
/**
 * <p></p>
 */
export declare class SubnetGroupAlreadyExistsFault extends __BaseException {
    readonly name: "SubnetGroupAlreadyExistsFault";
    readonly $fault: "client";
    /**
     * @internal
     */
    constructor(opts: __ExceptionOptionType<SubnetGroupAlreadyExistsFault, __BaseException>);
}
/**
 * <p></p>
 */
export declare class SubnetGroupQuotaExceededFault extends __BaseException {
    readonly name: "SubnetGroupQuotaExceededFault";
    readonly $fault: "client";
    /**
     * @internal
     */
    constructor(opts: __ExceptionOptionType<SubnetGroupQuotaExceededFault, __BaseException>);
}
/**
 * <p></p>
 */
export declare class SubnetNotAllowedFault extends __BaseException {
    readonly name: "SubnetNotAllowedFault";
    readonly $fault: "client";
    /**
     * @internal
     */
    constructor(opts: __ExceptionOptionType<SubnetNotAllowedFault, __BaseException>);
}
/**
 * <p></p>
 */
export declare class SubnetQuotaExceededFault extends __BaseException {
    readonly name: "SubnetQuotaExceededFault";
    readonly $fault: "client";
    /**
     * @internal
     */
    constructor(opts: __ExceptionOptionType<SubnetQuotaExceededFault, __BaseException>);
}
export declare enum InputAuthenticationType {
    PASSWORD = "password"
}
/**
 * <p>Denotes the user's authentication properties, such as whether it requires a password to authenticate. Used in output responses.</p>
 */
export interface AuthenticationMode {
    /**
     * <p>Indicates whether the user requires a password to authenticate. All newly-created users require a password.</p>
     */
    Type?: InputAuthenticationType | string;
    /**
     * <p>The password(s) used for authentication</p>
     */
    Passwords?: string[];
}
export declare namespace AuthenticationMode {
    /**
     * @internal
     */
    const filterSensitiveLog: (obj: AuthenticationMode) => any;
}
export interface CreateUserRequest {
    /**
     * <p>The name of the user. This value must be unique as it also serves as the user identifier.</p>
     */
    UserName: string | undefined;
    /**
     * <p>Denotes the user's authentication properties, such as whether it requires a password to authenticate.</p>
     */
    AuthenticationMode: AuthenticationMode | undefined;
    /**
     * <p>Access permissions string used for this user.</p>
     */
    AccessString: string | undefined;
    /**
     * <p>A list of tags to be added to this resource. A tag is a key-value pair. A tag key must be accompanied by a tag value, although null is accepted.</p>
     */
    Tags?: Tag[];
}
export declare namespace CreateUserRequest {
    /**
     * @internal
     */
    const filterSensitiveLog: (obj: CreateUserRequest) => any;
}
export declare enum AuthenticationType {
    NO_PASSWORD = "no-password",
    PASSWORD = "password"
}
/**
 * <p>Denotes the user's authentication properties, such as whether it requires a password to authenticate. Used in output responses.</p>
 */
export interface Authentication {
    /**
     * <p>Indicates whether the user requires a password to authenticate.</p>
     */
    Type?: AuthenticationType | string;
    /**
     * <p>The number of passwords belonging to the user. The maximum is two.</p>
     */
    PasswordCount?: number;
}
export declare namespace Authentication {
    /**
     * @internal
     */
    const filterSensitiveLog: (obj: Authentication) => any;
}
/**
 * <p>You create users and assign them specific permissions by using an access string. You assign the users to Access Control Lists aligned with a specific role (administrators, human resources) that are then deployed to one or more MemoryDB clusters.</p>
 */
export interface User {
    /**
     * <p>The name of the user</p>
     */
    Name?: string;
    /**
     * <p>Indicates the user status. Can be "active", "modifying" or "deleting".</p>
     */
    Status?: string;
    /**
     * <p>Access permissions string used for this user.</p>
     */
    AccessString?: string;
    /**
     * <p>The names of the Access Control Lists to which the user belongs</p>
     */
    ACLNames?: string[];
    /**
     * <p>The minimum engine version supported for the user</p>
     */
    MinimumEngineVersion?: string;
    /**
     * <p>Denotes whether the user requires a password to authenticate.</p>
     */
    Authentication?: Authentication;
    /**
     * <p>The Amazon Resource Name (ARN) of the user.
     *
     *       </p>
     */
    ARN?: string;
}
export declare namespace User {
    /**
     * @internal
     */
    const filterSensitiveLog: (obj: User) => any;
}
export interface CreateUserResponse {
    /**
     * <p>The newly-created user.</p>
     */
    User?: User;
}
export declare namespace CreateUserResponse {
    /**
     * @internal
     */
    const filterSensitiveLog: (obj: CreateUserResponse) => any;
}
/**
 * <p></p>
 */
export declare class UserAlreadyExistsFault extends __BaseException {
    readonly name: "UserAlreadyExistsFault";
    readonly $fault: "client";
    /**
     * @internal
     */
    constructor(opts: __ExceptionOptionType<UserAlreadyExistsFault, __BaseException>);
}
/**
 * <p></p>
 */
export declare class UserQuotaExceededFault extends __BaseException {
    readonly name: "UserQuotaExceededFault";
    readonly $fault: "client";
    /**
     * @internal
     */
    constructor(opts: __ExceptionOptionType<UserQuotaExceededFault, __BaseException>);
}
export interface DeleteACLRequest {
    /**
     * <p>The name of the Access Control List to delete</p>
     */
    ACLName: string | undefined;
}
export declare namespace DeleteACLRequest {
    /**
     * @internal
     */
    const filterSensitiveLog: (obj: DeleteACLRequest) => any;
}
export interface DeleteACLResponse {
    /**
     * <p>The Access Control List object that has been deleted.</p>
     */
    ACL?: ACL;
}
export declare namespace DeleteACLResponse {
    /**
     * @internal
     */
    const filterSensitiveLog: (obj: DeleteACLResponse) => any;
}
export interface DeleteClusterRequest {
    /**
     * <p>The name of the cluster to be deleted</p>
     */
    ClusterName: string | undefined;
    /**
     * <p>The user-supplied name of a final cluster snapshot. This is the unique name that identifies the snapshot. MemoryDB creates the snapshot, and then deletes the cluster immediately afterward.</p>
     */
    FinalSnapshotName?: string;
}
export declare namespace DeleteClusterRequest {
    /**
     * @internal
     */
    const filterSensitiveLog: (obj: DeleteClusterRequest) => any;
}
export interface DeleteClusterResponse {
    /**
     * <p>The cluster object that has been deleted</p>
     */
    Cluster?: Cluster;
}
export declare namespace DeleteClusterResponse {
    /**
     * @internal
     */
    const filterSensitiveLog: (obj: DeleteClusterResponse) => any;
}
export interface DeleteParameterGroupRequest {
    /**
     * <p>The name of the parameter group to delete.</p>
     */
    ParameterGroupName: string | undefined;
}
export declare namespace DeleteParameterGroupRequest {
    /**
     * @internal
     */
    const filterSensitiveLog: (obj: DeleteParameterGroupRequest) => any;
}
export interface DeleteParameterGroupResponse {
    /**
     * <p>The parameter group that has been deleted.</p>
     */
    ParameterGroup?: ParameterGroup;
}
export declare namespace DeleteParameterGroupResponse {
    /**
     * @internal
     */
    const filterSensitiveLog: (obj: DeleteParameterGroupResponse) => any;
}
export interface DeleteSnapshotRequest {
    /**
     * <p>The name of the snapshot to delete</p>
     */
    SnapshotName: string | undefined;
}
export declare namespace DeleteSnapshotRequest {
    /**
     * @internal
     */
    const filterSensitiveLog: (obj: DeleteSnapshotRequest) => any;
}
export interface DeleteSnapshotResponse {
    /**
     * <p>The snapshot object that has been deleted.</p>
     */
    Snapshot?: Snapshot;
}
export declare namespace DeleteSnapshotResponse {
    /**
     * @internal
     */
    const filterSensitiveLog: (obj: DeleteSnapshotResponse) => any;
}
export interface DeleteSubnetGroupRequest {
    /**
     * <p>The name of the subnet group to delete</p>
     */
    SubnetGroupName: string | undefined;
}
export declare namespace DeleteSubnetGroupRequest {
    /**
     * @internal
     */
    const filterSensitiveLog: (obj: DeleteSubnetGroupRequest) => any;
}
export interface DeleteSubnetGroupResponse {
    /**
     * <p>The subnet group object that has been deleted.</p>
     */
    SubnetGroup?: SubnetGroup;
}
export declare namespace DeleteSubnetGroupResponse {
    /**
     * @internal
     */
    const filterSensitiveLog: (obj: DeleteSubnetGroupResponse) => any;
}
/**
 * <p></p>
 */
export declare class SubnetGroupInUseFault extends __BaseException {
    readonly name: "SubnetGroupInUseFault";
    readonly $fault: "client";
    /**
     * @internal
     */
    constructor(opts: __ExceptionOptionType<SubnetGroupInUseFault, __BaseException>);
}
export interface DeleteUserRequest {
    /**
     * <p>The name of the user to delete</p>
     */
    UserName: string | undefined;
}
export declare namespace DeleteUserRequest {
    /**
     * @internal
     */
    const filterSensitiveLog: (obj: DeleteUserRequest) => any;
}
export interface DeleteUserResponse {
    /**
     * <p>The user object that has been deleted.</p>
     */
    User?: User;
}
export declare namespace DeleteUserResponse {
    /**
     * @internal
     */
    const filterSensitiveLog: (obj: DeleteUserResponse) => any;
}
/**
 * <p></p>
 */
export declare class InvalidUserStateFault extends __BaseException {
    readonly name: "InvalidUserStateFault";
    readonly $fault: "client";
    /**
     * @internal
     */
    constructor(opts: __ExceptionOptionType<InvalidUserStateFault, __BaseException>);
}
export interface DescribeACLsRequest {
    /**
     * <p>The name of the ACL</p>
     */
    ACLName?: string;
    /**
     * <p>The maximum number of records to include in the response. If more records exist than the specified MaxResults value, a token is included in the response so that the remaining results can be retrieved.</p>
     */
    MaxResults?: number;
    /**
     * <p>An optional argument to pass in case the total number of records exceeds the value of MaxResults. If nextToken is returned, there are more results available. The value of nextToken is a unique pagination token for each page. Make the call again using the returned token to retrieve the next page. Keep all other arguments unchanged. </p>
     */
    NextToken?: string;
}
export declare namespace DescribeACLsRequest {
    /**
     * @internal
     */
    const filterSensitiveLog: (obj: DescribeACLsRequest) => any;
}
export interface DescribeACLsResponse {
    /**
     * <p>The list of ACLs</p>
     */
    ACLs?: ACL[];
    /**
     * <p>If nextToken is returned, there are more results available. The value of nextToken is a unique pagination token for each page. Make the call again using the returned token to retrieve the next page. Keep all other arguments unchanged. </p>
     */
    NextToken?: string;
}
export declare namespace DescribeACLsResponse {
    /**
     * @internal
     */
    const filterSensitiveLog: (obj: DescribeACLsResponse) => any;
}
export interface DescribeClustersRequest {
    /**
     * <p>The name of the cluster</p>
     */
    ClusterName?: string;
    /**
     * <p>The maximum number of records to include in the response. If more records exist than the specified MaxResults value, a token is included in the response so that the remaining results can be retrieved.</p>
     */
    MaxResults?: number;
    /**
     * <p>An optional argument to pass in case the total number of records exceeds the value of MaxResults. If nextToken is returned, there are more results available. The value of nextToken is a unique pagination token for each page. Make the call again using the returned token to retrieve the next page. Keep all other arguments unchanged. </p>
     */
    NextToken?: string;
    /**
     * <p>An optional flag that can be included in the request to retrieve information about the individual shard(s).</p>
     */
    ShowShardDetails?: boolean;
}
export declare namespace DescribeClustersRequest {
    /**
     * @internal
     */
    const filterSensitiveLog: (obj: DescribeClustersRequest) => any;
}
export interface DescribeClustersResponse {
    /**
     * <p>An optional argument to pass in case the total number of records exceeds the value of MaxResults. If nextToken is returned, there are more results available. The value of nextToken is a unique pagination token for each page. Make the call again using the returned token to retrieve the next page. Keep all other arguments unchanged. </p>
     */
    NextToken?: string;
    /**
     * <p>A list of clusters</p>
     */
    Clusters?: Cluster[];
}
export declare namespace DescribeClustersResponse {
    /**
     * @internal
     */
    const filterSensitiveLog: (obj: DescribeClustersResponse) => any;
}
export interface DescribeEngineVersionsRequest {
    /**
     * <p>The Redis engine version</p>
     */
    EngineVersion?: string;
    /**
     * <p>The name of a specific parameter group family to return details for.</p>
     */
    ParameterGroupFamily?: string;
    /**
     * <p>The maximum number of records to include in the response. If more records exist than the specified MaxResults value, a token is included in the response so that the remaining results can be retrieved.</p>
     */
    MaxResults?: number;
    /**
     * <p>An optional argument to pass in case the total number of records exceeds the value of MaxResults. If nextToken is returned, there are more results available. The value of nextToken is a unique pagination token for each page. Make the call again using the returned token to retrieve the next page. Keep all other arguments unchanged. </p>
     */
    NextToken?: string;
    /**
     * <p>If true, specifies that only the default version of the specified engine or engine and major version combination is to be returned.</p>
     */
    DefaultOnly?: boolean;
}
export declare namespace DescribeEngineVersionsRequest {
    /**
     * @internal
     */
    const filterSensitiveLog: (obj: DescribeEngineVersionsRequest) => any;
}
/**
 * <p>Provides details of the Redis engine version</p>
 */
export interface EngineVersionInfo {
    /**
     * <p>The engine version</p>
     */
    EngineVersion?: string;
    /**
     * <p>The patched engine version</p>
     */
    EnginePatchVersion?: string;
    /**
     * <p>Specifies the name of the parameter group family to which the engine default parameters apply.</p>
     */
    ParameterGroupFamily?: string;
}
export declare namespace EngineVersionInfo {
    /**
     * @internal
     */
    const filterSensitiveLog: (obj: EngineVersionInfo) => any;
}
export interface DescribeEngineVersionsResponse {
    /**
     * <p>An optional argument to pass in case the total number of records exceeds the value of MaxResults. If nextToken is returned, there are more results available. The value of nextToken is a unique pagination token for each page. Make the call again using the returned token to retrieve the next page. Keep all other arguments unchanged. </p>
     */
    NextToken?: string;
    /**
     * <p>A list of engine version details. Each element in the list contains detailed information about one engine version.</p>
     */
    EngineVersions?: EngineVersionInfo[];
}
export declare namespace DescribeEngineVersionsResponse {
    /**
     * @internal
     */
    const filterSensitiveLog: (obj: DescribeEngineVersionsResponse) => any;
}
export declare enum SourceType {
    acl = "acl",
    cluster = "cluster",
    node = "node",
    parameter_group = "parameter-group",
    subnet_group = "subnet-group",
    user = "user"
}
export interface DescribeEventsRequest {
    /**
     * <p>The identifier of the event source for which events are returned. If not specified, all sources are included in the response.</p>
     */
    SourceName?: string;
    /**
     * <p>The event source to retrieve events for. If no value is specified, all events are returned.</p>
     */
    SourceType?: SourceType | string;
    /**
     * <p>The beginning of the time interval to retrieve events for, specified in ISO 8601 format.
     *
     *          Example: 2017-03-30T07:03:49.555Z</p>
     */
    StartTime?: Date;
    /**
     * <p>The end of the time interval for which to retrieve events, specified in ISO 8601 format.
     *
     *          Example: 2017-03-30T07:03:49.555Z</p>
     */
    EndTime?: Date;
    /**
     * <p>The number of minutes worth of events to retrieve.</p>
     */
    Duration?: number;
    /**
     * <p>The maximum number of records to include in the response. If more records exist than the specified MaxResults value, a token is included in the response so that the remaining results can be retrieved.</p>
     */
    MaxResults?: number;
    /**
     * <p>An optional argument to pass in case the total number of records exceeds the value of MaxResults. If nextToken is returned, there are more results available. The value of nextToken is a unique pagination token for each page. Make the call again using the returned token to retrieve the next page. Keep all other arguments unchanged. </p>
     */
    NextToken?: string;
}
export declare namespace DescribeEventsRequest {
    /**
     * @internal
     */
    const filterSensitiveLog: (obj: DescribeEventsRequest) => any;
}
/**
 * <p>Represents a single occurrence of something interesting within the system. Some examples of events are creating a cluster or adding or removing a
 *          node.</p>
 */
export interface Event {
    /**
     * <p>The name for the source of the event. For example, if the event occurred at the cluster level, the identifier would be the name of the cluster.</p>
     */
    SourceName?: string;
    /**
     * <p>Specifies the origin of this event - a cluster, a parameter group, a security group, etc.</p>
     */
    SourceType?: SourceType | string;
    /**
     * <p>The text of the event.</p>
     */
    Message?: string;
    /**
     * <p>The date and time when the event occurred.</p>
     */
    Date?: Date;
}
export declare namespace Event {
    /**
     * @internal
     */
    const filterSensitiveLog: (obj: Event) => any;
}
export interface DescribeEventsResponse {
    /**
     * <p>An optional argument to pass in case the total number of records exceeds the value of MaxResults. If nextToken is returned, there are more results available. The value of nextToken is a unique pagination token for each page. Make the call again using the returned token to retrieve the next page. Keep all other arguments unchanged. </p>
     */
    NextToken?: string;
    /**
     * <p>A list of events. Each element in the list contains detailed information about one event.</p>
     */
    Events?: Event[];
}
export declare namespace DescribeEventsResponse {
    /**
     * @internal
     */
    const filterSensitiveLog: (obj: DescribeEventsResponse) => any;
}
export interface DescribeParameterGroupsRequest {
    /**
     * <p>The name of a specific  parameter group to return details for.</p>
     */
    ParameterGroupName?: string;
    /**
     * <p>The maximum number of records to include in the response. If more records exist than the specified MaxResults value, a token is included in the response so that the remaining results can be retrieved.</p>
     */
    MaxResults?: number;
    /**
     * <p>An optional argument to pass in case the total number of records exceeds the value of MaxResults. If nextToken is returned, there are more results available. The value of nextToken is a unique pagination token for each page. Make the call again using the returned token to retrieve the next page. Keep all other arguments unchanged. </p>
     */
    NextToken?: string;
}
export declare namespace DescribeParameterGroupsRequest {
    /**
     * @internal
     */
    const filterSensitiveLog: (obj: DescribeParameterGroupsRequest) => any;
}
export interface DescribeParameterGroupsResponse {
    /**
     * <p>An optional argument to pass in case the total number of records exceeds the value of MaxResults. If nextToken is returned, there are more results available. The value of nextToken is a unique pagination token for each page. Make the call again using the returned token to retrieve the next page. Keep all other arguments unchanged. </p>
     */
    NextToken?: string;
    /**
     * <p>A list of parameter groups. Each element in the list contains detailed information about one parameter group.</p>
     */
    ParameterGroups?: ParameterGroup[];
}
export declare namespace DescribeParameterGroupsResponse {
    /**
     * @internal
     */
    const filterSensitiveLog: (obj: DescribeParameterGroupsResponse) => any;
}
export interface DescribeParametersRequest {
    /**
     * <p>he name of a specific  parameter group to return details for.</p>
     */
    ParameterGroupName: string | undefined;
    /**
     * <p>The maximum number of records to include in the response. If more records exist than the specified MaxResults value, a token is included in the response so that the remaining results can be retrieved.</p>
     */
    MaxResults?: number;
    /**
     * <p>An optional argument to pass in case the total number of records exceeds the value of MaxResults. If nextToken is returned, there are more results available. The value of nextToken is a unique pagination token for each page. Make the call again using the returned token to retrieve the next page. Keep all other arguments unchanged. </p>
     */
    NextToken?: string;
}
export declare namespace DescribeParametersRequest {
    /**
     * @internal
     */
    const filterSensitiveLog: (obj: DescribeParametersRequest) => any;
}
/**
 * <p>Describes an individual setting that controls some aspect of MemoryDB behavior.</p>
 */
export interface Parameter {
    /**
     * <p>The name of the parameter</p>
     */
    Name?: string;
    /**
     * <p>The value of the parameter</p>
     */
    Value?: string;
    /**
     * <p>A description of the parameter</p>
     */
    Description?: string;
    /**
     * <p>The parameter's data type</p>
     */
    DataType?: string;
    /**
     * <p>The valid range of values for the parameter.</p>
     */
    AllowedValues?: string;
    /**
     * <p>The earliest engine version to which the parameter can apply.</p>
     */
    MinimumEngineVersion?: string;
}
export declare namespace Parameter {
    /**
     * @internal
     */
    const filterSensitiveLog: (obj: Parameter) => any;
}
export interface DescribeParametersResponse {
    /**
     * <p>An optional argument to pass in case the total number of records exceeds the value of MaxResults. If nextToken is returned, there are more results available. The value of nextToken is a unique pagination token for each page. Make the call again using the returned token to retrieve the next page. Keep all other arguments unchanged. </p>
     */
    NextToken?: string;
    /**
     * <p>A list of parameters specific to a particular parameter group. Each element in the list contains detailed information about one parameter.</p>
     */
    Parameters?: Parameter[];
}
export declare namespace DescribeParametersResponse {
    /**
     * @internal
     */
    const filterSensitiveLog: (obj: DescribeParametersResponse) => any;
}
export interface DescribeServiceUpdatesRequest {
    /**
     * <p>The unique ID of the service update to describe.</p>
     */
    ServiceUpdateName?: string;
    /**
     * <p>The list of cluster names to identify service updates to apply</p>
     */
    ClusterNames?: string[];
    /**
     * <p>The status(es) of the service updates to filter on</p>
     */
    Status?: (ServiceUpdateStatus | string)[];
    /**
     * <p>The maximum number of records to include in the response. If more records exist than the specified MaxResults value, a token is included in the response so that the remaining results can be retrieved.</p>
     */
    MaxResults?: number;
    /**
     * <p>An optional argument to pass in case the total number of records exceeds the value of MaxResults. If nextToken is returned, there are more results available. The value of nextToken is a unique pagination token for each page. Make the call again using the returned token to retrieve the next page. Keep all other arguments unchanged. </p>
     */
    NextToken?: string;
}
export declare namespace DescribeServiceUpdatesRequest {
    /**
     * @internal
     */
    const filterSensitiveLog: (obj: DescribeServiceUpdatesRequest) => any;
}
export declare enum ServiceUpdateType {
    SECURITY_UPDATE = "security-update"
}
/**
 * <p>An update that you can apply to your MemoryDB clusters.</p>
 */
export interface ServiceUpdate {
    /**
     * <p>The name of the cluster to which the service update applies</p>
     */
    ClusterName?: string;
    /**
     * <p>The unique ID of the service update</p>
     */
    ServiceUpdateName?: string;
    /**
     * <p>The date when the service update is initially available</p>
     */
    ReleaseDate?: Date;
    /**
     * <p>Provides details of the service update</p>
     */
    Description?: string;
    /**
     * <p>The status of the service update</p>
     */
    Status?: ServiceUpdateStatus | string;
    /**
     * <p>Reflects the nature of the service update</p>
     */
    Type?: ServiceUpdateType | string;
    /**
     * <p>A list of nodes updated by the service update</p>
     */
    NodesUpdated?: string;
    /**
     * <p>The date at which the service update will be automatically applied</p>
     */
    AutoUpdateStartDate?: Date;
}
export declare namespace ServiceUpdate {
    /**
     * @internal
     */
    const filterSensitiveLog: (obj: ServiceUpdate) => any;
}
export interface DescribeServiceUpdatesResponse {
    /**
     * <p>An optional argument to pass in case the total number of records exceeds the value of MaxResults. If nextToken is returned, there are more results available. The value of nextToken is a unique pagination token for each page. Make the call again using the returned token to retrieve the next page. Keep all other arguments unchanged. </p>
     */
    NextToken?: string;
    /**
     * <p>A list of service updates</p>
     */
    ServiceUpdates?: ServiceUpdate[];
}
export declare namespace DescribeServiceUpdatesResponse {
    /**
     * @internal
     */
    const filterSensitiveLog: (obj: DescribeServiceUpdatesResponse) => any;
}
export interface DescribeSnapshotsRequest {
    /**
     * <p>A user-supplied cluster identifier. If this parameter is specified, only snapshots associated with that specific cluster are described.</p>
     */
    ClusterName?: string;
    /**
     * <p>A user-supplied name of the snapshot. If this parameter is specified, only this named snapshot is described.</p>
     */
    SnapshotName?: string;
    /**
     * <p>If set to system, the output shows snapshots that were automatically created by MemoryDB. If set to user the output shows snapshots that were manually created. If omitted, the output shows both automatically and manually created snapshots.</p>
     */
    Source?: string;
    /**
     * <p>An optional argument to pass in case the total number of records exceeds the value of MaxResults. If nextToken is returned, there are more results available. The value of nextToken is a unique pagination token for each page. Make the call again using the returned token to retrieve the next page. Keep all other arguments unchanged. </p>
     */
    NextToken?: string;
    /**
     * <p>The maximum number of records to include in the response. If more records exist than the specified MaxResults value, a token is included in the response so that the remaining results can be retrieved.</p>
     */
    MaxResults?: number;
    /**
     * <p>A Boolean value which if true, the shard configuration is included in the snapshot description.</p>
     */
    ShowDetail?: boolean;
}
export declare namespace DescribeSnapshotsRequest {
    /**
     * @internal
     */
    const filterSensitiveLog: (obj: DescribeSnapshotsRequest) => any;
}
export interface DescribeSnapshotsResponse {
    /**
     * <p>An optional argument to pass in case the total number of records exceeds the value of MaxResults. If nextToken is returned, there are more results available. The value of nextToken is a unique pagination token for each page. Make the call again using the returned token to retrieve the next page. Keep all other arguments unchanged. </p>
     */
    NextToken?: string;
    /**
     * <p>A list of snapshots. Each item in the list contains detailed information about one snapshot.</p>
     */
    Snapshots?: Snapshot[];
}
export declare namespace DescribeSnapshotsResponse {
    /**
     * @internal
     */
    const filterSensitiveLog: (obj: DescribeSnapshotsResponse) => any;
}
export interface DescribeSubnetGroupsRequest {
    /**
     * <p>The name of the subnet group to return details for.</p>
     */
    SubnetGroupName?: string;
    /**
     * <p>The maximum number of records to include in the response. If more records exist than the specified MaxResults value, a token is included in the response so that the remaining results can be retrieved.</p>
     */
    MaxResults?: number;
    /**
     * <p>An optional argument to pass in case the total number of records exceeds the value of MaxResults. If nextToken is returned, there are more results available. The value of nextToken is a unique pagination token for each page. Make the call again using the returned token to retrieve the next page. Keep all other arguments unchanged. </p>
     */
    NextToken?: string;
}
export declare namespace DescribeSubnetGroupsRequest {
    /**
     * @internal
     */
    const filterSensitiveLog: (obj: DescribeSubnetGroupsRequest) => any;
}
export interface DescribeSubnetGroupsResponse {
    /**
     * <p>An optional argument to pass in case the total number of records exceeds the value of MaxResults. If nextToken is returned, there are more results available. The value of nextToken is a unique pagination token for each page. Make the call again using the returned token to retrieve the next page. Keep all other arguments unchanged. </p>
     */
    NextToken?: string;
    /**
     * <p>A list of subnet groups. Each element in the list contains detailed information about one group.</p>
     */
    SubnetGroups?: SubnetGroup[];
}
export declare namespace DescribeSubnetGroupsResponse {
    /**
     * @internal
     */
    const filterSensitiveLog: (obj: DescribeSubnetGroupsResponse) => any;
}
/**
 * <p>Used to streamline results of a search based on the property being filtered.</p>
 */
export interface Filter {
    /**
     * <p>The property being filtered. For example, UserName.</p>
     */
    Name: string | undefined;
    /**
     * <p>The property values to filter on. For example, "user-123".</p>
     */
    Values: string[] | undefined;
}
export declare namespace Filter {
    /**
     * @internal
     */
    const filterSensitiveLog: (obj: Filter) => any;
}
export interface DescribeUsersRequest {
    /**
     * <p>The name of the user</p>
     */
    UserName?: string;
    /**
     * <p>Filter to determine the list of users to return.</p>
     */
    Filters?: Filter[];
    /**
     * <p>The maximum number of records to include in the response. If more records exist than the specified MaxResults value, a token is included in the response so that the remaining results can be retrieved.</p>
     */
    MaxResults?: number;
    /**
     * <p>An optional argument to pass in case the total number of records exceeds the value of MaxResults. If nextToken is returned, there are more results available. The value of nextToken is a unique pagination token for each page. Make the call again using the returned token to retrieve the next page. Keep all other arguments unchanged. </p>
     */
    NextToken?: string;
}
export declare namespace DescribeUsersRequest {
    /**
     * @internal
     */
    const filterSensitiveLog: (obj: DescribeUsersRequest) => any;
}
export interface DescribeUsersResponse {
    /**
     * <p>A list of users.</p>
     */
    Users?: User[];
    /**
     * <p>An optional argument to pass in case the total number of records exceeds the value of MaxResults. If nextToken is returned, there are more results available. The value of nextToken is a unique pagination token for each page. Make the call again using the returned token to retrieve the next page. Keep all other arguments unchanged. </p>
     */
    NextToken?: string;
}
export declare namespace DescribeUsersResponse {
    /**
     * @internal
     */
    const filterSensitiveLog: (obj: DescribeUsersResponse) => any;
}
/**
 * <p></p>
 */
export declare class APICallRateForCustomerExceededFault extends __BaseException {
    readonly name: "APICallRateForCustomerExceededFault";
    readonly $fault: "client";
    /**
     * @internal
     */
    constructor(opts: __ExceptionOptionType<APICallRateForCustomerExceededFault, __BaseException>);
}
export interface FailoverShardRequest {
    /**
     * <p>The cluster being failed over</p>
     */
    ClusterName: string | undefined;
    /**
     * <p>The name of the shard</p>
     */
    ShardName: string | undefined;
}
export declare namespace FailoverShardRequest {
    /**
     * @internal
     */
    const filterSensitiveLog: (obj: FailoverShardRequest) => any;
}
export interface FailoverShardResponse {
    /**
     * <p>The cluster being failed over</p>
     */
    Cluster?: Cluster;
}
export declare namespace FailoverShardResponse {
    /**
     * @internal
     */
    const filterSensitiveLog: (obj: FailoverShardResponse) => any;
}
/**
 * <p></p>
 */
export declare class InvalidKMSKeyFault extends __BaseException {
    readonly name: "InvalidKMSKeyFault";
    readonly $fault: "client";
    /**
     * @internal
     */
    constructor(opts: __ExceptionOptionType<InvalidKMSKeyFault, __BaseException>);
}
/**
 * <p></p>
 */
export declare class ShardNotFoundFault extends __BaseException {
    readonly name: "ShardNotFoundFault";
    readonly $fault: "client";
    /**
     * @internal
     */
    constructor(opts: __ExceptionOptionType<ShardNotFoundFault, __BaseException>);
}
/**
 * <p></p>
 */
export declare class TestFailoverNotAvailableFault extends __BaseException {
    readonly name: "TestFailoverNotAvailableFault";
    readonly $fault: "client";
    /**
     * @internal
     */
    constructor(opts: __ExceptionOptionType<TestFailoverNotAvailableFault, __BaseException>);
}
export interface ListAllowedNodeTypeUpdatesRequest {
    /**
     * <p>The name of the cluster you want to scale. MemoryDB uses the cluster name to identify the current node type being used by this cluster, and from that to create a list of node types
     *          you can scale up to.</p>
     */
    ClusterName: string | undefined;
}
export declare namespace ListAllowedNodeTypeUpdatesRequest {
    /**
     * @internal
     */
    const filterSensitiveLog: (obj: ListAllowedNodeTypeUpdatesRequest) => any;
}
export interface ListAllowedNodeTypeUpdatesResponse {
    /**
     * <p>A list node types which you can use to scale up your cluster.</p>
     */
    ScaleUpNodeTypes?: string[];
    /**
     * <p>A list node types which you can use to scale down your cluster.</p>
     */
    ScaleDownNodeTypes?: string[];
}
export declare namespace ListAllowedNodeTypeUpdatesResponse {
    /**
     * @internal
     */
    const filterSensitiveLog: (obj: ListAllowedNodeTypeUpdatesResponse) => any;
}
/**
 * <p></p>
 */
export declare class InvalidARNFault extends __BaseException {
    readonly name: "InvalidARNFault";
    readonly $fault: "client";
    /**
     * @internal
     */
    constructor(opts: __ExceptionOptionType<InvalidARNFault, __BaseException>);
}
export interface ListTagsRequest {
    /**
     * <p>The Amazon Resource Name (ARN) of the resource for which you want the list of tags</p>
     */
    ResourceArn: string | undefined;
}
export declare namespace ListTagsRequest {
    /**
     * @internal
     */
    const filterSensitiveLog: (obj: ListTagsRequest) => any;
}
export interface ListTagsResponse {
    /**
     * <p>A list of tags as key-value pairs.</p>
     */
    TagList?: Tag[];
}
export declare namespace ListTagsResponse {
    /**
     * @internal
     */
    const filterSensitiveLog: (obj: ListTagsResponse) => any;
}
export interface ResetParameterGroupRequest {
    /**
     * <p>The name of the parameter group to reset.</p>
     */
    ParameterGroupName: string | undefined;
    /**
     * <p>If true, all parameters in the parameter group are reset to their default values. If false, only the parameters listed by ParameterNames are reset to their default values.</p>
     */
    AllParameters?: boolean;
    /**
     * <p>An array of parameter names to reset to their default values. If AllParameters is true, do not use ParameterNames. If AllParameters is false, you must specify the name of at least one parameter to reset.</p>
     */
    ParameterNames?: string[];
}
export declare namespace ResetParameterGroupRequest {
    /**
     * @internal
     */
    const filterSensitiveLog: (obj: ResetParameterGroupRequest) => any;
}
export interface ResetParameterGroupResponse {
    /**
     * <p>The parameter group being reset.</p>
     */
    ParameterGroup?: ParameterGroup;
}
export declare namespace ResetParameterGroupResponse {
    /**
     * @internal
     */
    const filterSensitiveLog: (obj: ResetParameterGroupResponse) => any;
}
export interface TagResourceRequest {
    /**
     * <p>The Amazon Resource Name (ARN) of the resource to which the tags are to be added</p>
     */
    ResourceArn: string | undefined;
    /**
     * <p>A list of tags to be added to this resource. A tag is a key-value pair. A tag key must be accompanied by a tag value, although null is accepted.</p>
     */
    Tags: Tag[] | undefined;
}
export declare namespace TagResourceRequest {
    /**
     * @internal
     */
    const filterSensitiveLog: (obj: TagResourceRequest) => any;
}
export interface TagResourceResponse {
    /**
     * <p>A list of tags as key-value pairs.</p>
     */
    TagList?: Tag[];
}
export declare namespace TagResourceResponse {
    /**
     * @internal
     */
    const filterSensitiveLog: (obj: TagResourceResponse) => any;
}
/**
 * <p></p>
 */
export declare class TagNotFoundFault extends __BaseException {
    readonly name: "TagNotFoundFault";
    readonly $fault: "client";
    /**
     * @internal
     */
    constructor(opts: __ExceptionOptionType<TagNotFoundFault, __BaseException>);
}
export interface UntagResourceRequest {
    /**
     * <p>The Amazon Resource Name (ARN) of the resource to which the tags are to be removed</p>
     */
    ResourceArn: string | undefined;
    /**
     * <p>The list of keys of the tags that are to be removed</p>
     */
    TagKeys: string[] | undefined;
}
export declare namespace UntagResourceRequest {
    /**
     * @internal
     */
    const filterSensitiveLog: (obj: UntagResourceRequest) => any;
}
export interface UntagResourceResponse {
    /**
     * <p>The list of tags removed</p>
     */
    TagList?: Tag[];
}
export declare namespace UntagResourceResponse {
    /**
     * @internal
     */
    const filterSensitiveLog: (obj: UntagResourceResponse) => any;
}
export interface UpdateACLRequest {
    /**
     * <p>The name of the Access Control List</p>
     */
    ACLName: string | undefined;
    /**
     * <p>The list of users to add to the Access Control List</p>
     */
    UserNamesToAdd?: string[];
    /**
     * <p>The list of users to remove from the Access Control List</p>
     */
    UserNamesToRemove?: string[];
}
export declare namespace UpdateACLRequest {
    /**
     * @internal
     */
    const filterSensitiveLog: (obj: UpdateACLRequest) => any;
}
export interface UpdateACLResponse {
    /**
     * <p>The updated Access Control List</p>
     */
    ACL?: ACL;
}
export declare namespace UpdateACLResponse {
    /**
     * @internal
     */
    const filterSensitiveLog: (obj: UpdateACLResponse) => any;
}
/**
 * <p></p>
 */
export declare class InvalidNodeStateFault extends __BaseException {
    readonly name: "InvalidNodeStateFault";
    readonly $fault: "client";
    /**
     * @internal
     */
    constructor(opts: __ExceptionOptionType<InvalidNodeStateFault, __BaseException>);
}
/**
 * <p></p>
 */
export declare class NoOperationFault extends __BaseException {
    readonly name: "NoOperationFault";
    readonly $fault: "client";
    /**
     * @internal
     */
    constructor(opts: __ExceptionOptionType<NoOperationFault, __BaseException>);
}
/**
 * <p>A request to configure the number of replicas in a shard</p>
 */
export interface ReplicaConfigurationRequest {
    /**
     * <p>The number of replicas to scale up or down to</p>
     */
    ReplicaCount?: number;
}
export declare namespace ReplicaConfigurationRequest {
    /**
     * @internal
     */
    const filterSensitiveLog: (obj: ReplicaConfigurationRequest) => any;
}
/**
 * <p>A request to configure the sharding properties of a cluster</p>
 */
export interface ShardConfigurationRequest {
    /**
     * <p>The number of shards in the cluster</p>
     */
    ShardCount?: number;
}
export declare namespace ShardConfigurationRequest {
    /**
     * @internal
     */
    const filterSensitiveLog: (obj: ShardConfigurationRequest) => any;
}
export interface UpdateClusterRequest {
    /**
     * <p>The name of the cluster to update</p>
     */
    ClusterName: string | undefined;
    /**
     * <p>The description of the cluster to update</p>
     */
    Description?: string;
    /**
     * <p>The SecurityGroupIds to update</p>
     */
    SecurityGroupIds?: string[];
    /**
     * <p>The maintenance window to update</p>
     */
    MaintenanceWindow?: string;
    /**
     * <p>The SNS topic ARN to update</p>
     */
    SnsTopicArn?: string;
    /**
     * <p>The status of the Amazon SNS notification topic. Notifications are sent only if the status is active.</p>
     */
    SnsTopicStatus?: string;
    /**
     * <p>The name of the parameter group to update</p>
     */
    ParameterGroupName?: string;
    /**
     * <p>The daily time range (in UTC) during which MemoryDB begins taking a daily snapshot of your cluster.</p>
     */
    SnapshotWindow?: string;
    /**
     * <p>The number of days for which MemoryDB retains automatic cluster snapshots before deleting them. For example, if you set SnapshotRetentionLimit to 5, a snapshot that was taken today is retained for 5 days before being deleted.</p>
     */
    SnapshotRetentionLimit?: number;
    /**
     * <p>A valid node type that you want to scale this cluster up or down to.</p>
     */
    NodeType?: string;
    /**
     * <p>The upgraded version of the engine to be run on the nodes. You can upgrade to a newer engine version, but you cannot downgrade to an earlier engine version. If you want to use an earlier engine version, you must delete the existing cluster and create it anew with the earlier engine version.</p>
     */
    EngineVersion?: string;
    /**
     * <p>The number of replicas that will reside in each shard</p>
     */
    ReplicaConfiguration?: ReplicaConfigurationRequest;
    /**
     * <p>The number of shards in the cluster</p>
     */
    ShardConfiguration?: ShardConfigurationRequest;
    /**
     * <p>The Access Control List that is associated with the cluster</p>
     */
    ACLName?: string;
}
export declare namespace UpdateClusterRequest {
    /**
     * @internal
     */
    const filterSensitiveLog: (obj: UpdateClusterRequest) => any;
}
export interface UpdateClusterResponse {
    /**
     * <p>The updated cluster</p>
     */
    Cluster?: Cluster;
}
export declare namespace UpdateClusterResponse {
    /**
     * @internal
     */
    const filterSensitiveLog: (obj: UpdateClusterResponse) => any;
}
/**
 * <p>Describes a name-value pair that is used to update the value of a parameter.</p>
 */
export interface ParameterNameValue {
    /**
     * <p>The name of the parameter</p>
     */
    ParameterName?: string;
    /**
     * <p>The value of the parameter</p>
     */
    ParameterValue?: string;
}
export declare namespace ParameterNameValue {
    /**
     * @internal
     */
    const filterSensitiveLog: (obj: ParameterNameValue) => any;
}
export interface UpdateParameterGroupRequest {
    /**
     * <p>The name of the parameter group to update.</p>
     */
    ParameterGroupName: string | undefined;
    /**
     * <p>An array of parameter names and values for the parameter update. You must supply at least one parameter name and value; subsequent arguments are optional. A maximum of 20 parameters may be updated per request.</p>
     */
    ParameterNameValues: ParameterNameValue[] | undefined;
}
export declare namespace UpdateParameterGroupRequest {
    /**
     * @internal
     */
    const filterSensitiveLog: (obj: UpdateParameterGroupRequest) => any;
}
export interface UpdateParameterGroupResponse {
    /**
     * <p>The updated parameter group</p>
     */
    ParameterGroup?: ParameterGroup;
}
export declare namespace UpdateParameterGroupResponse {
    /**
     * @internal
     */
    const filterSensitiveLog: (obj: UpdateParameterGroupResponse) => any;
}
/**
 * <p></p>
 */
export declare class SubnetInUse extends __BaseException {
    readonly name: "SubnetInUse";
    readonly $fault: "client";
    /**
     * @internal
     */
    constructor(opts: __ExceptionOptionType<SubnetInUse, __BaseException>);
}
export interface UpdateSubnetGroupRequest {
    /**
     * <p>The name of the subnet group</p>
     */
    SubnetGroupName: string | undefined;
    /**
     * <p>A description of the subnet group</p>
     */
    Description?: string;
    /**
     * <p>The EC2 subnet IDs for the subnet group.</p>
     */
    SubnetIds?: string[];
}
export declare namespace UpdateSubnetGroupRequest {
    /**
     * @internal
     */
    const filterSensitiveLog: (obj: UpdateSubnetGroupRequest) => any;
}
export interface UpdateSubnetGroupResponse {
    /**
     * <p>The updated subnet group</p>
     */
    SubnetGroup?: SubnetGroup;
}
export declare namespace UpdateSubnetGroupResponse {
    /**
     * @internal
     */
    const filterSensitiveLog: (obj: UpdateSubnetGroupResponse) => any;
}
export interface UpdateUserRequest {
    /**
     * <p>The name of the user</p>
     */
    UserName: string | undefined;
    /**
     * <p>Denotes the user's authentication properties, such as whether it requires a password to authenticate.</p>
     */
    AuthenticationMode?: AuthenticationMode;
    /**
     * <p>Access permissions string used for this user.</p>
     */
    AccessString?: string;
}
export declare namespace UpdateUserRequest {
    /**
     * @internal
     */
    const filterSensitiveLog: (obj: UpdateUserRequest) => any;
}
export interface UpdateUserResponse {
    /**
     * <p>The updated user</p>
     */
    User?: User;
}
export declare namespace UpdateUserResponse {
    /**
     * @internal
     */
    const filterSensitiveLog: (obj: UpdateUserResponse) => any;
}
