import { ExceptionOptionType as __ExceptionOptionType } from "@aws-sdk/smithy-client";
import { MemoryDBServiceException as __BaseException } from "./MemoryDBServiceException";

export interface ACLPendingChanges {
    
    UserNamesToRemove?: string[];
    
    UserNamesToAdd?: string[];
}
export declare namespace ACLPendingChanges {
    
    const filterSensitiveLog: (obj: ACLPendingChanges) => any;
}

export interface ACL {
    
    Name?: string;
    
    Status?: string;
    
    UserNames?: string[];
    
    MinimumEngineVersion?: string;
    
    PendingChanges?: ACLPendingChanges;
    
    Clusters?: string[];
    
    ARN?: string;
}
export declare namespace ACL {
    
    const filterSensitiveLog: (obj: ACL) => any;
}

export declare class ACLAlreadyExistsFault extends __BaseException {
    readonly name: "ACLAlreadyExistsFault";
    readonly $fault: "client";
    
    constructor(opts: __ExceptionOptionType<ACLAlreadyExistsFault, __BaseException>);
}

export declare class ACLNotFoundFault extends __BaseException {
    readonly name: "ACLNotFoundFault";
    readonly $fault: "client";
    
    constructor(opts: __ExceptionOptionType<ACLNotFoundFault, __BaseException>);
}

export declare class ACLQuotaExceededFault extends __BaseException {
    readonly name: "ACLQuotaExceededFault";
    readonly $fault: "client";
    
    constructor(opts: __ExceptionOptionType<ACLQuotaExceededFault, __BaseException>);
}

export interface ACLsUpdateStatus {
    
    ACLToApply?: string;
}
export declare namespace ACLsUpdateStatus {
    
    const filterSensitiveLog: (obj: ACLsUpdateStatus) => any;
}

export interface ServiceUpdateRequest {
    
    ServiceUpdateNameToApply?: string;
}
export declare namespace ServiceUpdateRequest {
    
    const filterSensitiveLog: (obj: ServiceUpdateRequest) => any;
}
export interface BatchUpdateClusterRequest {
    
    ClusterNames: string[] | undefined;
    
    ServiceUpdate?: ServiceUpdateRequest;
}
export declare namespace BatchUpdateClusterRequest {
    
    const filterSensitiveLog: (obj: BatchUpdateClusterRequest) => any;
}
export declare enum AZStatus {
    MultiAZ = "multiaz",
    SingleAZ = "singleaz"
}

export interface Endpoint {
    
    Address?: string;
    
    Port?: number;
}
export declare namespace Endpoint {
    
    const filterSensitiveLog: (obj: Endpoint) => any;
}

export interface SlotMigration {
    
    ProgressPercentage?: number;
}
export declare namespace SlotMigration {
    
    const filterSensitiveLog: (obj: SlotMigration) => any;
}

export interface ReshardingStatus {
    
    SlotMigration?: SlotMigration;
}
export declare namespace ReshardingStatus {
    
    const filterSensitiveLog: (obj: ReshardingStatus) => any;
}
export declare enum ServiceUpdateStatus {
    COMPLETE = "complete",
    IN_PROGRESS = "in-progress",
    NOT_APPLIED = "available",
    SCHEDULED = "scheduled"
}

export interface PendingModifiedServiceUpdate {
    
    ServiceUpdateName?: string;
    
    Status?: ServiceUpdateStatus | string;
}
export declare namespace PendingModifiedServiceUpdate {
    
    const filterSensitiveLog: (obj: PendingModifiedServiceUpdate) => any;
}

export interface ClusterPendingUpdates {
    
    Resharding?: ReshardingStatus;
    
    ACLs?: ACLsUpdateStatus;
    
    ServiceUpdates?: PendingModifiedServiceUpdate[];
}
export declare namespace ClusterPendingUpdates {
    
    const filterSensitiveLog: (obj: ClusterPendingUpdates) => any;
}

export interface SecurityGroupMembership {
    
    SecurityGroupId?: string;
    
    Status?: string;
}
export declare namespace SecurityGroupMembership {
    
    const filterSensitiveLog: (obj: SecurityGroupMembership) => any;
}

export interface Node {
    
    Name?: string;
    
    Status?: string;
    
    AvailabilityZone?: string;
    
    CreateTime?: Date;
    
    Endpoint?: Endpoint;
}
export declare namespace Node {
    
    const filterSensitiveLog: (obj: Node) => any;
}

export interface Shard {
    
    Name?: string;
    
    Status?: string;
    
    Slots?: string;
    
    Nodes?: Node[];
    
    NumberOfNodes?: number;
}
export declare namespace Shard {
    
    const filterSensitiveLog: (obj: Shard) => any;
}

export interface Cluster {
    
    Name?: string;
    
    Description?: string;
    
    Status?: string;
    
    PendingUpdates?: ClusterPendingUpdates;
    
    NumberOfShards?: number;
    
    Shards?: Shard[];
    
    AvailabilityMode?: AZStatus | string;
    
    ClusterEndpoint?: Endpoint;
    
    NodeType?: string;
    
    EngineVersion?: string;
    
    EnginePatchVersion?: string;
    
    ParameterGroupName?: string;
    
    ParameterGroupStatus?: string;
    
    SecurityGroups?: SecurityGroupMembership[];
    
    SubnetGroupName?: string;
    
    TLSEnabled?: boolean;
    
    KmsKeyId?: string;
    
    ARN?: string;
    
    SnsTopicArn?: string;
    
    SnsTopicStatus?: string;
    
    SnapshotRetentionLimit?: number;
    
    MaintenanceWindow?: string;
    
    SnapshotWindow?: string;
    
    ACLName?: string;
    
    AutoMinorVersionUpgrade?: boolean;
}
export declare namespace Cluster {
    
    const filterSensitiveLog: (obj: Cluster) => any;
}

export interface UnprocessedCluster {
    
    ClusterName?: string;
    
    ErrorType?: string;
    
    ErrorMessage?: string;
}
export declare namespace UnprocessedCluster {
    
    const filterSensitiveLog: (obj: UnprocessedCluster) => any;
}
export interface BatchUpdateClusterResponse {
    
    ProcessedClusters?: Cluster[];
    
    UnprocessedClusters?: UnprocessedCluster[];
}
export declare namespace BatchUpdateClusterResponse {
    
    const filterSensitiveLog: (obj: BatchUpdateClusterResponse) => any;
}

export declare class InvalidParameterValueException extends __BaseException {
    readonly name: "InvalidParameterValueException";
    readonly $fault: "client";
    
    constructor(opts: __ExceptionOptionType<InvalidParameterValueException, __BaseException>);
}

export declare class ServiceUpdateNotFoundFault extends __BaseException {
    readonly name: "ServiceUpdateNotFoundFault";
    readonly $fault: "client";
    
    constructor(opts: __ExceptionOptionType<ServiceUpdateNotFoundFault, __BaseException>);
}

export interface Tag {
    
    Key?: string;
    
    Value?: string;
}
export declare namespace Tag {
    
    const filterSensitiveLog: (obj: Tag) => any;
}
export interface CopySnapshotRequest {
    
    SourceSnapshotName: string | undefined;
    
    TargetSnapshotName: string | undefined;
    
    TargetBucket?: string;
    
    KmsKeyId?: string;
    
    Tags?: Tag[];
}
export declare namespace CopySnapshotRequest {
    
    const filterSensitiveLog: (obj: CopySnapshotRequest) => any;
}

export interface ShardConfiguration {
    
    Slots?: string;
    
    ReplicaCount?: number;
}
export declare namespace ShardConfiguration {
    
    const filterSensitiveLog: (obj: ShardConfiguration) => any;
}

export interface ShardDetail {
    
    Name?: string;
    
    Configuration?: ShardConfiguration;
    
    Size?: string;
    
    SnapshotCreationTime?: Date;
}
export declare namespace ShardDetail {
    
    const filterSensitiveLog: (obj: ShardDetail) => any;
}

export interface ClusterConfiguration {
    
    Name?: string;
    
    Description?: string;
    
    NodeType?: string;
    
    EngineVersion?: string;
    
    MaintenanceWindow?: string;
    
    TopicArn?: string;
    
    Port?: number;
    
    ParameterGroupName?: string;
    
    SubnetGroupName?: string;
    
    VpcId?: string;
    
    SnapshotRetentionLimit?: number;
    
    SnapshotWindow?: string;
    
    NumShards?: number;
    
    Shards?: ShardDetail[];
}
export declare namespace ClusterConfiguration {
    
    const filterSensitiveLog: (obj: ClusterConfiguration) => any;
}

export interface Snapshot {
    
    Name?: string;
    
    Status?: string;
    
    Source?: string;
    
    KmsKeyId?: string;
    
    ARN?: string;
    
    ClusterConfiguration?: ClusterConfiguration;
}
export declare namespace Snapshot {
    
    const filterSensitiveLog: (obj: Snapshot) => any;
}
export interface CopySnapshotResponse {
    
    Snapshot?: Snapshot;
}
export declare namespace CopySnapshotResponse {
    
    const filterSensitiveLog: (obj: CopySnapshotResponse) => any;
}

export declare class InvalidParameterCombinationException extends __BaseException {
    readonly name: "InvalidParameterCombinationException";
    readonly $fault: "client";
    
    constructor(opts: __ExceptionOptionType<InvalidParameterCombinationException, __BaseException>);
}

export declare class InvalidSnapshotStateFault extends __BaseException {
    readonly name: "InvalidSnapshotStateFault";
    readonly $fault: "client";
    
    constructor(opts: __ExceptionOptionType<InvalidSnapshotStateFault, __BaseException>);
}

export declare class ServiceLinkedRoleNotFoundFault extends __BaseException {
    readonly name: "ServiceLinkedRoleNotFoundFault";
    readonly $fault: "client";
    
    constructor(opts: __ExceptionOptionType<ServiceLinkedRoleNotFoundFault, __BaseException>);
}

export declare class SnapshotAlreadyExistsFault extends __BaseException {
    readonly name: "SnapshotAlreadyExistsFault";
    readonly $fault: "client";
    
    constructor(opts: __ExceptionOptionType<SnapshotAlreadyExistsFault, __BaseException>);
}

export declare class SnapshotNotFoundFault extends __BaseException {
    readonly name: "SnapshotNotFoundFault";
    readonly $fault: "client";
    
    constructor(opts: __ExceptionOptionType<SnapshotNotFoundFault, __BaseException>);
}

export declare class SnapshotQuotaExceededFault extends __BaseException {
    readonly name: "SnapshotQuotaExceededFault";
    readonly $fault: "client";
    
    constructor(opts: __ExceptionOptionType<SnapshotQuotaExceededFault, __BaseException>);
}

export declare class TagQuotaPerResourceExceeded extends __BaseException {
    readonly name: "TagQuotaPerResourceExceeded";
    readonly $fault: "client";
    
    constructor(opts: __ExceptionOptionType<TagQuotaPerResourceExceeded, __BaseException>);
}
export interface CreateACLRequest {
    
    ACLName: string | undefined;
    
    UserNames?: string[];
    
    Tags?: Tag[];
}
export declare namespace CreateACLRequest {
    
    const filterSensitiveLog: (obj: CreateACLRequest) => any;
}
export interface CreateACLResponse {
    
    ACL?: ACL;
}
export declare namespace CreateACLResponse {
    
    const filterSensitiveLog: (obj: CreateACLResponse) => any;
}

export declare class DefaultUserRequired extends __BaseException {
    readonly name: "DefaultUserRequired";
    readonly $fault: "client";
    
    constructor(opts: __ExceptionOptionType<DefaultUserRequired, __BaseException>);
}

export declare class DuplicateUserNameFault extends __BaseException {
    readonly name: "DuplicateUserNameFault";
    readonly $fault: "client";
    
    constructor(opts: __ExceptionOptionType<DuplicateUserNameFault, __BaseException>);
}

export declare class UserNotFoundFault extends __BaseException {
    readonly name: "UserNotFoundFault";
    readonly $fault: "client";
    
    constructor(opts: __ExceptionOptionType<UserNotFoundFault, __BaseException>);
}

export declare class ClusterAlreadyExistsFault extends __BaseException {
    readonly name: "ClusterAlreadyExistsFault";
    readonly $fault: "client";
    
    constructor(opts: __ExceptionOptionType<ClusterAlreadyExistsFault, __BaseException>);
}

export declare class ClusterQuotaForCustomerExceededFault extends __BaseException {
    readonly name: "ClusterQuotaForCustomerExceededFault";
    readonly $fault: "client";
    
    constructor(opts: __ExceptionOptionType<ClusterQuotaForCustomerExceededFault, __BaseException>);
}
export interface CreateClusterRequest {
    
    ClusterName: string | undefined;
    
    NodeType: string | undefined;
    
    ParameterGroupName?: string;
    
    Description?: string;
    
    NumShards?: number;
    
    NumReplicasPerShard?: number;
    
    SubnetGroupName?: string;
    
    SecurityGroupIds?: string[];
    
    MaintenanceWindow?: string;
    
    Port?: number;
    
    SnsTopicArn?: string;
    
    TLSEnabled?: boolean;
    
    KmsKeyId?: string;
    
    SnapshotArns?: string[];
    
    SnapshotName?: string;
    
    SnapshotRetentionLimit?: number;
    
    Tags?: Tag[];
    
    SnapshotWindow?: string;
    
    ACLName: string | undefined;
    
    EngineVersion?: string;
    
    AutoMinorVersionUpgrade?: boolean;
}
export declare namespace CreateClusterRequest {
    
    const filterSensitiveLog: (obj: CreateClusterRequest) => any;
}
export interface CreateClusterResponse {
    
    Cluster?: Cluster;
}
export declare namespace CreateClusterResponse {
    
    const filterSensitiveLog: (obj: CreateClusterResponse) => any;
}

export declare class InsufficientClusterCapacityFault extends __BaseException {
    readonly name: "InsufficientClusterCapacityFault";
    readonly $fault: "client";
    
    constructor(opts: __ExceptionOptionType<InsufficientClusterCapacityFault, __BaseException>);
}

export declare class InvalidACLStateFault extends __BaseException {
    readonly name: "InvalidACLStateFault";
    readonly $fault: "client";
    
    constructor(opts: __ExceptionOptionType<InvalidACLStateFault, __BaseException>);
}

export declare class InvalidCredentialsException extends __BaseException {
    readonly name: "InvalidCredentialsException";
    readonly $fault: "client";
    
    constructor(opts: __ExceptionOptionType<InvalidCredentialsException, __BaseException>);
}

export declare class InvalidVPCNetworkStateFault extends __BaseException {
    readonly name: "InvalidVPCNetworkStateFault";
    readonly $fault: "client";
    
    constructor(opts: __ExceptionOptionType<InvalidVPCNetworkStateFault, __BaseException>);
}

export declare class NodeQuotaForClusterExceededFault extends __BaseException {
    readonly name: "NodeQuotaForClusterExceededFault";
    readonly $fault: "client";
    
    constructor(opts: __ExceptionOptionType<NodeQuotaForClusterExceededFault, __BaseException>);
}

export declare class NodeQuotaForCustomerExceededFault extends __BaseException {
    readonly name: "NodeQuotaForCustomerExceededFault";
    readonly $fault: "client";
    
    constructor(opts: __ExceptionOptionType<NodeQuotaForCustomerExceededFault, __BaseException>);
}

export declare class ParameterGroupNotFoundFault extends __BaseException {
    readonly name: "ParameterGroupNotFoundFault";
    readonly $fault: "client";
    
    constructor(opts: __ExceptionOptionType<ParameterGroupNotFoundFault, __BaseException>);
}

export declare class ShardsPerClusterQuotaExceededFault extends __BaseException {
    readonly name: "ShardsPerClusterQuotaExceededFault";
    readonly $fault: "client";
    
    constructor(opts: __ExceptionOptionType<ShardsPerClusterQuotaExceededFault, __BaseException>);
}

export declare class SubnetGroupNotFoundFault extends __BaseException {
    readonly name: "SubnetGroupNotFoundFault";
    readonly $fault: "client";
    
    constructor(opts: __ExceptionOptionType<SubnetGroupNotFoundFault, __BaseException>);
}
export interface CreateParameterGroupRequest {
    
    ParameterGroupName: string | undefined;
    
    Family: string | undefined;
    
    Description?: string;
    
    Tags?: Tag[];
}
export declare namespace CreateParameterGroupRequest {
    
    const filterSensitiveLog: (obj: CreateParameterGroupRequest) => any;
}

export interface ParameterGroup {
    
    Name?: string;
    
    Family?: string;
    
    Description?: string;
    
    ARN?: string;
}
export declare namespace ParameterGroup {
    
    const filterSensitiveLog: (obj: ParameterGroup) => any;
}
export interface CreateParameterGroupResponse {
    
    ParameterGroup?: ParameterGroup;
}
export declare namespace CreateParameterGroupResponse {
    
    const filterSensitiveLog: (obj: CreateParameterGroupResponse) => any;
}

export declare class InvalidParameterGroupStateFault extends __BaseException {
    readonly name: "InvalidParameterGroupStateFault";
    readonly $fault: "client";
    
    constructor(opts: __ExceptionOptionType<InvalidParameterGroupStateFault, __BaseException>);
}

export declare class ParameterGroupAlreadyExistsFault extends __BaseException {
    readonly name: "ParameterGroupAlreadyExistsFault";
    readonly $fault: "client";
    
    constructor(opts: __ExceptionOptionType<ParameterGroupAlreadyExistsFault, __BaseException>);
}

export declare class ParameterGroupQuotaExceededFault extends __BaseException {
    readonly name: "ParameterGroupQuotaExceededFault";
    readonly $fault: "client";
    
    constructor(opts: __ExceptionOptionType<ParameterGroupQuotaExceededFault, __BaseException>);
}

export declare class ClusterNotFoundFault extends __BaseException {
    readonly name: "ClusterNotFoundFault";
    readonly $fault: "client";
    
    constructor(opts: __ExceptionOptionType<ClusterNotFoundFault, __BaseException>);
}
export interface CreateSnapshotRequest {
    
    ClusterName: string | undefined;
    
    SnapshotName: string | undefined;
    
    KmsKeyId?: string;
    
    Tags?: Tag[];
}
export declare namespace CreateSnapshotRequest {
    
    const filterSensitiveLog: (obj: CreateSnapshotRequest) => any;
}
export interface CreateSnapshotResponse {
    
    Snapshot?: Snapshot;
}
export declare namespace CreateSnapshotResponse {
    
    const filterSensitiveLog: (obj: CreateSnapshotResponse) => any;
}

export declare class InvalidClusterStateFault extends __BaseException {
    readonly name: "InvalidClusterStateFault";
    readonly $fault: "client";
    
    constructor(opts: __ExceptionOptionType<InvalidClusterStateFault, __BaseException>);
}
export interface CreateSubnetGroupRequest {
    
    SubnetGroupName: string | undefined;
    
    Description?: string;
    
    SubnetIds: string[] | undefined;
    
    Tags?: Tag[];
}
export declare namespace CreateSubnetGroupRequest {
    
    const filterSensitiveLog: (obj: CreateSubnetGroupRequest) => any;
}

export interface AvailabilityZone {
    
    Name?: string;
}
export declare namespace AvailabilityZone {
    
    const filterSensitiveLog: (obj: AvailabilityZone) => any;
}

export interface Subnet {
    
    Identifier?: string;
    
    AvailabilityZone?: AvailabilityZone;
}
export declare namespace Subnet {
    
    const filterSensitiveLog: (obj: Subnet) => any;
}

export interface SubnetGroup {
    
    Name?: string;
    
    Description?: string;
    
    VpcId?: string;
    
    Subnets?: Subnet[];
    
    ARN?: string;
}
export declare namespace SubnetGroup {
    
    const filterSensitiveLog: (obj: SubnetGroup) => any;
}
export interface CreateSubnetGroupResponse {
    
    SubnetGroup?: SubnetGroup;
}
export declare namespace CreateSubnetGroupResponse {
    
    const filterSensitiveLog: (obj: CreateSubnetGroupResponse) => any;
}

export declare class InvalidSubnet extends __BaseException {
    readonly name: "InvalidSubnet";
    readonly $fault: "client";
    
    constructor(opts: __ExceptionOptionType<InvalidSubnet, __BaseException>);
}

export declare class SubnetGroupAlreadyExistsFault extends __BaseException {
    readonly name: "SubnetGroupAlreadyExistsFault";
    readonly $fault: "client";
    
    constructor(opts: __ExceptionOptionType<SubnetGroupAlreadyExistsFault, __BaseException>);
}

export declare class SubnetGroupQuotaExceededFault extends __BaseException {
    readonly name: "SubnetGroupQuotaExceededFault";
    readonly $fault: "client";
    
    constructor(opts: __ExceptionOptionType<SubnetGroupQuotaExceededFault, __BaseException>);
}

export declare class SubnetNotAllowedFault extends __BaseException {
    readonly name: "SubnetNotAllowedFault";
    readonly $fault: "client";
    
    constructor(opts: __ExceptionOptionType<SubnetNotAllowedFault, __BaseException>);
}

export declare class SubnetQuotaExceededFault extends __BaseException {
    readonly name: "SubnetQuotaExceededFault";
    readonly $fault: "client";
    
    constructor(opts: __ExceptionOptionType<SubnetQuotaExceededFault, __BaseException>);
}
export declare enum InputAuthenticationType {
    PASSWORD = "password"
}

export interface AuthenticationMode {
    
    Type?: InputAuthenticationType | string;
    
    Passwords?: string[];
}
export declare namespace AuthenticationMode {
    
    const filterSensitiveLog: (obj: AuthenticationMode) => any;
}
export interface CreateUserRequest {
    
    UserName: string | undefined;
    
    AuthenticationMode: AuthenticationMode | undefined;
    
    AccessString: string | undefined;
    
    Tags?: Tag[];
}
export declare namespace CreateUserRequest {
    
    const filterSensitiveLog: (obj: CreateUserRequest) => any;
}
export declare enum AuthenticationType {
    NO_PASSWORD = "no-password",
    PASSWORD = "password"
}

export interface Authentication {
    
    Type?: AuthenticationType | string;
    
    PasswordCount?: number;
}
export declare namespace Authentication {
    
    const filterSensitiveLog: (obj: Authentication) => any;
}

export interface User {
    
    Name?: string;
    
    Status?: string;
    
    AccessString?: string;
    
    ACLNames?: string[];
    
    MinimumEngineVersion?: string;
    
    Authentication?: Authentication;
    
    ARN?: string;
}
export declare namespace User {
    
    const filterSensitiveLog: (obj: User) => any;
}
export interface CreateUserResponse {
    
    User?: User;
}
export declare namespace CreateUserResponse {
    
    const filterSensitiveLog: (obj: CreateUserResponse) => any;
}

export declare class UserAlreadyExistsFault extends __BaseException {
    readonly name: "UserAlreadyExistsFault";
    readonly $fault: "client";
    
    constructor(opts: __ExceptionOptionType<UserAlreadyExistsFault, __BaseException>);
}

export declare class UserQuotaExceededFault extends __BaseException {
    readonly name: "UserQuotaExceededFault";
    readonly $fault: "client";
    
    constructor(opts: __ExceptionOptionType<UserQuotaExceededFault, __BaseException>);
}
export interface DeleteACLRequest {
    
    ACLName: string | undefined;
}
export declare namespace DeleteACLRequest {
    
    const filterSensitiveLog: (obj: DeleteACLRequest) => any;
}
export interface DeleteACLResponse {
    
    ACL?: ACL;
}
export declare namespace DeleteACLResponse {
    
    const filterSensitiveLog: (obj: DeleteACLResponse) => any;
}
export interface DeleteClusterRequest {
    
    ClusterName: string | undefined;
    
    FinalSnapshotName?: string;
}
export declare namespace DeleteClusterRequest {
    
    const filterSensitiveLog: (obj: DeleteClusterRequest) => any;
}
export interface DeleteClusterResponse {
    
    Cluster?: Cluster;
}
export declare namespace DeleteClusterResponse {
    
    const filterSensitiveLog: (obj: DeleteClusterResponse) => any;
}
export interface DeleteParameterGroupRequest {
    
    ParameterGroupName: string | undefined;
}
export declare namespace DeleteParameterGroupRequest {
    
    const filterSensitiveLog: (obj: DeleteParameterGroupRequest) => any;
}
export interface DeleteParameterGroupResponse {
    
    ParameterGroup?: ParameterGroup;
}
export declare namespace DeleteParameterGroupResponse {
    
    const filterSensitiveLog: (obj: DeleteParameterGroupResponse) => any;
}
export interface DeleteSnapshotRequest {
    
    SnapshotName: string | undefined;
}
export declare namespace DeleteSnapshotRequest {
    
    const filterSensitiveLog: (obj: DeleteSnapshotRequest) => any;
}
export interface DeleteSnapshotResponse {
    
    Snapshot?: Snapshot;
}
export declare namespace DeleteSnapshotResponse {
    
    const filterSensitiveLog: (obj: DeleteSnapshotResponse) => any;
}
export interface DeleteSubnetGroupRequest {
    
    SubnetGroupName: string | undefined;
}
export declare namespace DeleteSubnetGroupRequest {
    
    const filterSensitiveLog: (obj: DeleteSubnetGroupRequest) => any;
}
export interface DeleteSubnetGroupResponse {
    
    SubnetGroup?: SubnetGroup;
}
export declare namespace DeleteSubnetGroupResponse {
    
    const filterSensitiveLog: (obj: DeleteSubnetGroupResponse) => any;
}

export declare class SubnetGroupInUseFault extends __BaseException {
    readonly name: "SubnetGroupInUseFault";
    readonly $fault: "client";
    
    constructor(opts: __ExceptionOptionType<SubnetGroupInUseFault, __BaseException>);
}
export interface DeleteUserRequest {
    
    UserName: string | undefined;
}
export declare namespace DeleteUserRequest {
    
    const filterSensitiveLog: (obj: DeleteUserRequest) => any;
}
export interface DeleteUserResponse {
    
    User?: User;
}
export declare namespace DeleteUserResponse {
    
    const filterSensitiveLog: (obj: DeleteUserResponse) => any;
}

export declare class InvalidUserStateFault extends __BaseException {
    readonly name: "InvalidUserStateFault";
    readonly $fault: "client";
    
    constructor(opts: __ExceptionOptionType<InvalidUserStateFault, __BaseException>);
}
export interface DescribeACLsRequest {
    
    ACLName?: string;
    
    MaxResults?: number;
    
    NextToken?: string;
}
export declare namespace DescribeACLsRequest {
    
    const filterSensitiveLog: (obj: DescribeACLsRequest) => any;
}
export interface DescribeACLsResponse {
    
    ACLs?: ACL[];
    
    NextToken?: string;
}
export declare namespace DescribeACLsResponse {
    
    const filterSensitiveLog: (obj: DescribeACLsResponse) => any;
}
export interface DescribeClustersRequest {
    
    ClusterName?: string;
    
    MaxResults?: number;
    
    NextToken?: string;
    
    ShowShardDetails?: boolean;
}
export declare namespace DescribeClustersRequest {
    
    const filterSensitiveLog: (obj: DescribeClustersRequest) => any;
}
export interface DescribeClustersResponse {
    
    NextToken?: string;
    
    Clusters?: Cluster[];
}
export declare namespace DescribeClustersResponse {
    
    const filterSensitiveLog: (obj: DescribeClustersResponse) => any;
}
export interface DescribeEngineVersionsRequest {
    
    EngineVersion?: string;
    
    ParameterGroupFamily?: string;
    
    MaxResults?: number;
    
    NextToken?: string;
    
    DefaultOnly?: boolean;
}
export declare namespace DescribeEngineVersionsRequest {
    
    const filterSensitiveLog: (obj: DescribeEngineVersionsRequest) => any;
}

export interface EngineVersionInfo {
    
    EngineVersion?: string;
    
    EnginePatchVersion?: string;
    
    ParameterGroupFamily?: string;
}
export declare namespace EngineVersionInfo {
    
    const filterSensitiveLog: (obj: EngineVersionInfo) => any;
}
export interface DescribeEngineVersionsResponse {
    
    NextToken?: string;
    
    EngineVersions?: EngineVersionInfo[];
}
export declare namespace DescribeEngineVersionsResponse {
    
    const filterSensitiveLog: (obj: DescribeEngineVersionsResponse) => any;
}
export declare enum SourceType {
    acl = "acl",
    cluster = "cluster",
    node = "node",
    parameter_group = "parameter-group",
    subnet_group = "subnet-group",
    user = "user"
}
export interface DescribeEventsRequest {
    
    SourceName?: string;
    
    SourceType?: SourceType | string;
    
    StartTime?: Date;
    
    EndTime?: Date;
    
    Duration?: number;
    
    MaxResults?: number;
    
    NextToken?: string;
}
export declare namespace DescribeEventsRequest {
    
    const filterSensitiveLog: (obj: DescribeEventsRequest) => any;
}

export interface Event {
    
    SourceName?: string;
    
    SourceType?: SourceType | string;
    
    Message?: string;
    
    Date?: Date;
}
export declare namespace Event {
    
    const filterSensitiveLog: (obj: Event) => any;
}
export interface DescribeEventsResponse {
    
    NextToken?: string;
    
    Events?: Event[];
}
export declare namespace DescribeEventsResponse {
    
    const filterSensitiveLog: (obj: DescribeEventsResponse) => any;
}
export interface DescribeParameterGroupsRequest {
    
    ParameterGroupName?: string;
    
    MaxResults?: number;
    
    NextToken?: string;
}
export declare namespace DescribeParameterGroupsRequest {
    
    const filterSensitiveLog: (obj: DescribeParameterGroupsRequest) => any;
}
export interface DescribeParameterGroupsResponse {
    
    NextToken?: string;
    
    ParameterGroups?: ParameterGroup[];
}
export declare namespace DescribeParameterGroupsResponse {
    
    const filterSensitiveLog: (obj: DescribeParameterGroupsResponse) => any;
}
export interface DescribeParametersRequest {
    
    ParameterGroupName: string | undefined;
    
    MaxResults?: number;
    
    NextToken?: string;
}
export declare namespace DescribeParametersRequest {
    
    const filterSensitiveLog: (obj: DescribeParametersRequest) => any;
}

export interface Parameter {
    
    Name?: string;
    
    Value?: string;
    
    Description?: string;
    
    DataType?: string;
    
    AllowedValues?: string;
    
    MinimumEngineVersion?: string;
}
export declare namespace Parameter {
    
    const filterSensitiveLog: (obj: Parameter) => any;
}
export interface DescribeParametersResponse {
    
    NextToken?: string;
    
    Parameters?: Parameter[];
}
export declare namespace DescribeParametersResponse {
    
    const filterSensitiveLog: (obj: DescribeParametersResponse) => any;
}
export interface DescribeServiceUpdatesRequest {
    
    ServiceUpdateName?: string;
    
    ClusterNames?: string[];
    
    Status?: (ServiceUpdateStatus | string)[];
    
    MaxResults?: number;
    
    NextToken?: string;
}
export declare namespace DescribeServiceUpdatesRequest {
    
    const filterSensitiveLog: (obj: DescribeServiceUpdatesRequest) => any;
}
export declare enum ServiceUpdateType {
    SECURITY_UPDATE = "security-update"
}

export interface ServiceUpdate {
    
    ClusterName?: string;
    
    ServiceUpdateName?: string;
    
    ReleaseDate?: Date;
    
    Description?: string;
    
    Status?: ServiceUpdateStatus | string;
    
    Type?: ServiceUpdateType | string;
    
    NodesUpdated?: string;
    
    AutoUpdateStartDate?: Date;
}
export declare namespace ServiceUpdate {
    
    const filterSensitiveLog: (obj: ServiceUpdate) => any;
}
export interface DescribeServiceUpdatesResponse {
    
    NextToken?: string;
    
    ServiceUpdates?: ServiceUpdate[];
}
export declare namespace DescribeServiceUpdatesResponse {
    
    const filterSensitiveLog: (obj: DescribeServiceUpdatesResponse) => any;
}
export interface DescribeSnapshotsRequest {
    
    ClusterName?: string;
    
    SnapshotName?: string;
    
    Source?: string;
    
    NextToken?: string;
    
    MaxResults?: number;
    
    ShowDetail?: boolean;
}
export declare namespace DescribeSnapshotsRequest {
    
    const filterSensitiveLog: (obj: DescribeSnapshotsRequest) => any;
}
export interface DescribeSnapshotsResponse {
    
    NextToken?: string;
    
    Snapshots?: Snapshot[];
}
export declare namespace DescribeSnapshotsResponse {
    
    const filterSensitiveLog: (obj: DescribeSnapshotsResponse) => any;
}
export interface DescribeSubnetGroupsRequest {
    
    SubnetGroupName?: string;
    
    MaxResults?: number;
    
    NextToken?: string;
}
export declare namespace DescribeSubnetGroupsRequest {
    
    const filterSensitiveLog: (obj: DescribeSubnetGroupsRequest) => any;
}
export interface DescribeSubnetGroupsResponse {
    
    NextToken?: string;
    
    SubnetGroups?: SubnetGroup[];
}
export declare namespace DescribeSubnetGroupsResponse {
    
    const filterSensitiveLog: (obj: DescribeSubnetGroupsResponse) => any;
}

export interface Filter {
    
    Name: string | undefined;
    
    Values: string[] | undefined;
}
export declare namespace Filter {
    
    const filterSensitiveLog: (obj: Filter) => any;
}
export interface DescribeUsersRequest {
    
    UserName?: string;
    
    Filters?: Filter[];
    
    MaxResults?: number;
    
    NextToken?: string;
}
export declare namespace DescribeUsersRequest {
    
    const filterSensitiveLog: (obj: DescribeUsersRequest) => any;
}
export interface DescribeUsersResponse {
    
    Users?: User[];
    
    NextToken?: string;
}
export declare namespace DescribeUsersResponse {
    
    const filterSensitiveLog: (obj: DescribeUsersResponse) => any;
}

export declare class APICallRateForCustomerExceededFault extends __BaseException {
    readonly name: "APICallRateForCustomerExceededFault";
    readonly $fault: "client";
    
    constructor(opts: __ExceptionOptionType<APICallRateForCustomerExceededFault, __BaseException>);
}
export interface FailoverShardRequest {
    
    ClusterName: string | undefined;
    
    ShardName: string | undefined;
}
export declare namespace FailoverShardRequest {
    
    const filterSensitiveLog: (obj: FailoverShardRequest) => any;
}
export interface FailoverShardResponse {
    
    Cluster?: Cluster;
}
export declare namespace FailoverShardResponse {
    
    const filterSensitiveLog: (obj: FailoverShardResponse) => any;
}

export declare class InvalidKMSKeyFault extends __BaseException {
    readonly name: "InvalidKMSKeyFault";
    readonly $fault: "client";
    
    constructor(opts: __ExceptionOptionType<InvalidKMSKeyFault, __BaseException>);
}

export declare class ShardNotFoundFault extends __BaseException {
    readonly name: "ShardNotFoundFault";
    readonly $fault: "client";
    
    constructor(opts: __ExceptionOptionType<ShardNotFoundFault, __BaseException>);
}

export declare class TestFailoverNotAvailableFault extends __BaseException {
    readonly name: "TestFailoverNotAvailableFault";
    readonly $fault: "client";
    
    constructor(opts: __ExceptionOptionType<TestFailoverNotAvailableFault, __BaseException>);
}
export interface ListAllowedNodeTypeUpdatesRequest {
    
    ClusterName: string | undefined;
}
export declare namespace ListAllowedNodeTypeUpdatesRequest {
    
    const filterSensitiveLog: (obj: ListAllowedNodeTypeUpdatesRequest) => any;
}
export interface ListAllowedNodeTypeUpdatesResponse {
    
    ScaleUpNodeTypes?: string[];
    
    ScaleDownNodeTypes?: string[];
}
export declare namespace ListAllowedNodeTypeUpdatesResponse {
    
    const filterSensitiveLog: (obj: ListAllowedNodeTypeUpdatesResponse) => any;
}

export declare class InvalidARNFault extends __BaseException {
    readonly name: "InvalidARNFault";
    readonly $fault: "client";
    
    constructor(opts: __ExceptionOptionType<InvalidARNFault, __BaseException>);
}
export interface ListTagsRequest {
    
    ResourceArn: string | undefined;
}
export declare namespace ListTagsRequest {
    
    const filterSensitiveLog: (obj: ListTagsRequest) => any;
}
export interface ListTagsResponse {
    
    TagList?: Tag[];
}
export declare namespace ListTagsResponse {
    
    const filterSensitiveLog: (obj: ListTagsResponse) => any;
}
export interface ResetParameterGroupRequest {
    
    ParameterGroupName: string | undefined;
    
    AllParameters?: boolean;
    
    ParameterNames?: string[];
}
export declare namespace ResetParameterGroupRequest {
    
    const filterSensitiveLog: (obj: ResetParameterGroupRequest) => any;
}
export interface ResetParameterGroupResponse {
    
    ParameterGroup?: ParameterGroup;
}
export declare namespace ResetParameterGroupResponse {
    
    const filterSensitiveLog: (obj: ResetParameterGroupResponse) => any;
}
export interface TagResourceRequest {
    
    ResourceArn: string | undefined;
    
    Tags: Tag[] | undefined;
}
export declare namespace TagResourceRequest {
    
    const filterSensitiveLog: (obj: TagResourceRequest) => any;
}
export interface TagResourceResponse {
    
    TagList?: Tag[];
}
export declare namespace TagResourceResponse {
    
    const filterSensitiveLog: (obj: TagResourceResponse) => any;
}

export declare class TagNotFoundFault extends __BaseException {
    readonly name: "TagNotFoundFault";
    readonly $fault: "client";
    
    constructor(opts: __ExceptionOptionType<TagNotFoundFault, __BaseException>);
}
export interface UntagResourceRequest {
    
    ResourceArn: string | undefined;
    
    TagKeys: string[] | undefined;
}
export declare namespace UntagResourceRequest {
    
    const filterSensitiveLog: (obj: UntagResourceRequest) => any;
}
export interface UntagResourceResponse {
    
    TagList?: Tag[];
}
export declare namespace UntagResourceResponse {
    
    const filterSensitiveLog: (obj: UntagResourceResponse) => any;
}
export interface UpdateACLRequest {
    
    ACLName: string | undefined;
    
    UserNamesToAdd?: string[];
    
    UserNamesToRemove?: string[];
}
export declare namespace UpdateACLRequest {
    
    const filterSensitiveLog: (obj: UpdateACLRequest) => any;
}
export interface UpdateACLResponse {
    
    ACL?: ACL;
}
export declare namespace UpdateACLResponse {
    
    const filterSensitiveLog: (obj: UpdateACLResponse) => any;
}

export declare class InvalidNodeStateFault extends __BaseException {
    readonly name: "InvalidNodeStateFault";
    readonly $fault: "client";
    
    constructor(opts: __ExceptionOptionType<InvalidNodeStateFault, __BaseException>);
}

export declare class NoOperationFault extends __BaseException {
    readonly name: "NoOperationFault";
    readonly $fault: "client";
    
    constructor(opts: __ExceptionOptionType<NoOperationFault, __BaseException>);
}

export interface ReplicaConfigurationRequest {
    
    ReplicaCount?: number;
}
export declare namespace ReplicaConfigurationRequest {
    
    const filterSensitiveLog: (obj: ReplicaConfigurationRequest) => any;
}

export interface ShardConfigurationRequest {
    
    ShardCount?: number;
}
export declare namespace ShardConfigurationRequest {
    
    const filterSensitiveLog: (obj: ShardConfigurationRequest) => any;
}
export interface UpdateClusterRequest {
    
    ClusterName: string | undefined;
    
    Description?: string;
    
    SecurityGroupIds?: string[];
    
    MaintenanceWindow?: string;
    
    SnsTopicArn?: string;
    
    SnsTopicStatus?: string;
    
    ParameterGroupName?: string;
    
    SnapshotWindow?: string;
    
    SnapshotRetentionLimit?: number;
    
    NodeType?: string;
    
    EngineVersion?: string;
    
    ReplicaConfiguration?: ReplicaConfigurationRequest;
    
    ShardConfiguration?: ShardConfigurationRequest;
    
    ACLName?: string;
}
export declare namespace UpdateClusterRequest {
    
    const filterSensitiveLog: (obj: UpdateClusterRequest) => any;
}
export interface UpdateClusterResponse {
    
    Cluster?: Cluster;
}
export declare namespace UpdateClusterResponse {
    
    const filterSensitiveLog: (obj: UpdateClusterResponse) => any;
}

export interface ParameterNameValue {
    
    ParameterName?: string;
    
    ParameterValue?: string;
}
export declare namespace ParameterNameValue {
    
    const filterSensitiveLog: (obj: ParameterNameValue) => any;
}
export interface UpdateParameterGroupRequest {
    
    ParameterGroupName: string | undefined;
    
    ParameterNameValues: ParameterNameValue[] | undefined;
}
export declare namespace UpdateParameterGroupRequest {
    
    const filterSensitiveLog: (obj: UpdateParameterGroupRequest) => any;
}
export interface UpdateParameterGroupResponse {
    
    ParameterGroup?: ParameterGroup;
}
export declare namespace UpdateParameterGroupResponse {
    
    const filterSensitiveLog: (obj: UpdateParameterGroupResponse) => any;
}

export declare class SubnetInUse extends __BaseException {
    readonly name: "SubnetInUse";
    readonly $fault: "client";
    
    constructor(opts: __ExceptionOptionType<SubnetInUse, __BaseException>);
}
export interface UpdateSubnetGroupRequest {
    
    SubnetGroupName: string | undefined;
    
    Description?: string;
    
    SubnetIds?: string[];
}
export declare namespace UpdateSubnetGroupRequest {
    
    const filterSensitiveLog: (obj: UpdateSubnetGroupRequest) => any;
}
export interface UpdateSubnetGroupResponse {
    
    SubnetGroup?: SubnetGroup;
}
export declare namespace UpdateSubnetGroupResponse {
    
    const filterSensitiveLog: (obj: UpdateSubnetGroupResponse) => any;
}
export interface UpdateUserRequest {
    
    UserName: string | undefined;
    
    AuthenticationMode?: AuthenticationMode;
    
    AccessString?: string;
}
export declare namespace UpdateUserRequest {
    
    const filterSensitiveLog: (obj: UpdateUserRequest) => any;
}
export interface UpdateUserResponse {
    
    User?: User;
}
export declare namespace UpdateUserResponse {
    
    const filterSensitiveLog: (obj: UpdateUserResponse) => any;
}
